@@ -20,12 +20,10 @@ package resume
 import (
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
-	"github.com/apache/camel-k/v2/pkg/metadata"
 	"github.com/apache/camel-k/v2/pkg/trait"
 	"github.com/apache/camel-k/v2/pkg/util"
-	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
-	"github.com/apache/camel-k/v2/pkg/util/log"
-	"k8s.io/utils/pointer"
+	corev1 "k8s.io/api/core/v1"
+	"k8s.io/utils/ptr"
 )
 
 // The Resume trait can be used to manage and configure resume strategies.
@@ -36,6 +34,8 @@ import (
 //
 // The Resume trait is disabled by default.
 //
+// WARNING: The trait is **deprecated** and will removed in future release versions: configure directly the Camel properties as required by the component instead.
+//
 // The main different from the implementation on Core is that it's not necessary to bind the strategies to the
 // registry. This step will be done automatically by Camel K, after resolving the options passed to the trait.
 //
@@ -44,9 +44,11 @@ import (
 // -t resume.enabled=true -t resume.resume-path=camel-file-sets -t resume.resume-server="address-of-your-kafka:9092"
 //
 // +camel-k:trait=resume.
+// +camel-k:deprecated=2.5.0.
 type Trait struct {
 	traitv1.Trait `property:",squash"`
 	// Enables automatic configuration of the trait.
+	// Deprecated: not in use.
 	Auto *bool `property:"auto" json:"auto,omitempty"`
 	// The type of the resume strategy to use
 	ResumeStrategy string `property:"resume-strategy,omitempty"`
@@ -65,8 +67,8 @@ type resumeTrait struct {
 }
 
 const (
-	KafkaSingle  = "org.apache.camel.processor.resume.kafka.SingleNodeKafkaResumeStrategy"
-	StrategyPath = "camel-k-offsets"
+	kafkaSingle  = "org.apache.camel.processor.resume.kafka.SingleNodeKafkaResumeStrategy"
+	strategyPath = "camel-k-offsets"
 )
 
 func NewResumeTrait() trait.Trait {
@@ -76,42 +78,23 @@ func NewResumeTrait() trait.Trait {
 }
 
 func (r *resumeTrait) Configure(environment *trait.Environment) (bool, *trait.TraitCondition, error) {
-	if !pointer.BoolDeref(r.Enabled, false) {
+	if !ptr.Deref(r.Enabled, false) {
 		return false, nil, nil
 	}
-	if environment.CamelCatalog == nil {
-		return false, trait.NewIntegrationConditionPlatformDisabledCatalogMissing(), nil
-	}
 	if !environment.IntegrationInPhase(v1.IntegrationPhaseInitialization) && !environment.IntegrationInRunningPhases() {
 		return false, nil, nil
 	}
 
-	if pointer.BoolDeref(r.Auto, true) {
-		// Check which components have been used
-		sources, err := kubernetes.ResolveIntegrationSources(environment.Ctx, r.Client, environment.Integration, environment.Resources)
-		if err != nil {
-			return false, nil, err
-		}
+	condition := trait.NewIntegrationCondition(
+		"Resume",
+		v1.IntegrationConditionTraitInfo,
+		corev1.ConditionTrue,
+		trait.TraitConfigurationReason,
+		"Resume trait is deprecated and may be removed in future version: "+
+			"configure directly the Camel properties as required by the component instead",
+	)
 
-		meta, err := metadata.ExtractAll(environment.CamelCatalog, sources)
-		if err != nil {
-			return false, nil, err
-		}
-
-		for _, endpoint := range meta.FromURIs {
-			log.Infof("Processing component %s", endpoint)
-		}
-
-		if r.ResumeStrategy == "" {
-			r.ResumeStrategy = KafkaSingle
-		}
-
-		if r.ResumePath == "" {
-			r.ResumePath = StrategyPath
-		}
-	}
-
-	return r.Enabled != nil && *r.Enabled, nil, nil
+	return ptr.Deref(r.Enabled, false), condition, nil
 }
 
 func (r *resumeTrait) Apply(environment *trait.Environment) error {
@@ -121,11 +104,27 @@ func (r *resumeTrait) Apply(environment *trait.Environment) error {
 
 	if environment.IntegrationInRunningPhases() {
 		environment.ApplicationProperties["customizer.resume.enabled"] = "true"
-		environment.ApplicationProperties["customizer.resume.resumeStrategy"] = r.ResumeStrategy
-		environment.ApplicationProperties["customizer.resume.resumePath"] = r.ResumePath
+		environment.ApplicationProperties["customizer.resume.resumeStrategy"] = r.getResumeStrategy()
+		environment.ApplicationProperties["customizer.resume.resumePath"] = r.getResumePath()
 		environment.ApplicationProperties["customizer.resume.resumeServer"] = r.ResumeServer
 		environment.ApplicationProperties["customizer.resume.cacheFillPolicy"] = r.CacheFillPolicy
 	}
 
 	return nil
 }
+
+func (r *resumeTrait) getResumeStrategy() string {
+	if r.ResumeStrategy == "" {
+		return kafkaSingle
+	}
+
+	return r.ResumeStrategy
+}
+
+func (r *resumeTrait) getResumePath() string {
+	if r.ResumePath == "" {
+		return strategyPath
+	}
+
+	return r.ResumePath
+}
