@@ -18,7 +18,6 @@ limitations under the License.
 package azure
 
 import (
-	"regexp"
 	"strconv"
 
 	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
@@ -27,7 +26,8 @@ import (
 	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
 	"github.com/apache/camel-k/v2/pkg/trait"
 	"github.com/apache/camel-k/v2/pkg/util"
-	"k8s.io/utils/pointer"
+	corev1 "k8s.io/api/core/v1"
+	"k8s.io/utils/ptr"
 )
 
 // The Azure Key Vault trait can be used to use secrets from Azure Key Vault service
@@ -44,7 +44,10 @@ import (
 // the following trait options:
 // -t azure-key-vault.enabled=true -t azure-key-vault.tenant-id="tenant-id" -t azure-key-vault.client-id="client-id" -t azure-key-vault.client-secret="client-secret" -t azure-key-vault.vault-name="vault-name" -t azure-key-vault.context-reload-enabled="true" -t azure-key-vault.refresh-enabled="true" -t azure-key-vault.refresh-period="30000" -t azure-key-vault.secrets="test*" -t azure-key-vault.eventhub-connection-string="connection-string" -t azure-key-vault.blob-account-name="account-name"  -t azure-key-vault.blob-container-name="container-name"  -t azure-key-vault.blob-access-key="account-name" -t azure-key-vault.azure-identity-enabled="true"
 //
+// WARNING: The trait is **deprecated** and will removed in future release versions: configure directly the Camel properties as required by the component instead.
+//
 // +camel-k:trait=azure-key-vault.
+// +camel-k:deprecated=2.5.0.
 type Trait struct {
 	traitv1.Trait `property:",squash"`
 	// Enables automatic configuration of the trait.
@@ -81,10 +84,6 @@ type Trait struct {
 	BlobContainerName string `property:"blob-container-name" json:"blobContainerName,omitempty"`
 }
 
-var (
-	azureKeyValueRex = regexp.MustCompile(`^(configmap|secret):([a-zA-Z0-9][a-zA-Z0-9-]*)(/([a-zA-Z0-9].*))?$`)
-)
-
 type azureKeyVaultTrait struct {
 	trait.BaseTrait
 	Trait `property:",squash"`
@@ -97,7 +96,7 @@ func NewAzureKeyVaultTrait() trait.Trait {
 }
 
 func (t *azureKeyVaultTrait) Configure(environment *trait.Environment) (bool, *trait.TraitCondition, error) {
-	if environment.Integration == nil || !pointer.BoolDeref(t.Enabled, false) {
+	if environment.Integration == nil || !ptr.Deref(t.Enabled, false) {
 		return false, nil, nil
 	}
 
@@ -106,18 +105,27 @@ func (t *azureKeyVaultTrait) Configure(environment *trait.Environment) (bool, *t
 	}
 
 	if t.ContextReloadEnabled == nil {
-		t.ContextReloadEnabled = pointer.Bool(false)
+		t.ContextReloadEnabled = ptr.To(false)
 	}
 
 	if t.RefreshEnabled == nil {
-		t.RefreshEnabled = pointer.Bool(false)
+		t.RefreshEnabled = ptr.To(false)
 	}
 
 	if t.AzureIdentityEnabled == nil {
-		t.AzureIdentityEnabled = pointer.Bool(false)
+		t.AzureIdentityEnabled = ptr.To(false)
 	}
 
-	return true, nil, nil
+	condition := trait.NewIntegrationCondition(
+		"AzureKeyVault",
+		v1.IntegrationConditionTraitInfo,
+		corev1.ConditionTrue,
+		trait.TraitConfigurationReason,
+		"AzureKeyVault trait is deprecated and may be removed in future version: "+
+			"configure directly the Camel properties as required by the component instead",
+	)
+
+	return true, condition, nil
 }
 
 func (t *azureKeyVaultTrait) Apply(environment *trait.Environment) error {
@@ -130,7 +138,7 @@ func (t *azureKeyVaultTrait) Apply(environment *trait.Environment) error {
 		return nil
 	}
 
-	hits := azureKeyValueRex.FindAllStringSubmatch(t.ClientSecret, -1)
+	hits := v1.PlainConfigSecretRegexp.FindAllStringSubmatch(t.ClientSecret, -1)
 	if len(hits) >= 1 {
 		var res, _ = v1.DecodeValueSource(t.ClientSecret, "azure-key-vault-client-secret", "The Azure Key Vault Client Secret provided is not valid")
 		if secretValue, err := kubernetes.ResolveValueSource(environment.Ctx, environment.Client, environment.Platform.Namespace, &res); err != nil {
@@ -141,7 +149,7 @@ func (t *azureKeyVaultTrait) Apply(environment *trait.Environment) error {
 	} else {
 		environment.ApplicationProperties["camel.vault.azure.clientSecret"] = t.ClientSecret
 	}
-	hits = azureKeyValueRex.FindAllStringSubmatch(t.BlobAccessKey, -1)
+	hits = v1.PlainConfigSecretRegexp.FindAllStringSubmatch(t.BlobAccessKey, -1)
 	if len(hits) >= 1 {
 		var res, _ = v1.DecodeValueSource(t.BlobAccessKey, "azure-storage-blob-access-key", "The Azure Storage Blob Access Key provided is not valid")
 		if secretValue, err := kubernetes.ResolveValueSource(environment.Ctx, environment.Client, environment.Platform.Namespace, &res); err != nil {
