@@ -36,6 +36,7 @@ import (
 	"reflect"
 	"regexp"
 	"runtime/debug"
+	"sort"
 	"strings"
 	"sync"
 	"testing"
@@ -61,7 +62,7 @@ import (
 	"k8s.io/apimachinery/pkg/runtime/serializer"
 	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/client-go/rest"
-	"k8s.io/utils/pointer"
+	"k8s.io/utils/ptr"
 
 	ctrl "sigs.k8s.io/controller-runtime/pkg/client"
 	"sigs.k8s.io/controller-runtime/pkg/client/apiutil"
@@ -420,7 +421,33 @@ func IntegrationLogs(t *testing.T, ctx context.Context, ns, name string) func()
 		}
 
 		options := corev1.PodLogOptions{
-			TailLines: pointer.Int64(100),
+			TailLines: ptr.To(int64(100)),
+		}
+
+		for _, container := range pod.Status.ContainerStatuses {
+			if !container.Ready || container.State.Waiting != nil {
+				// avoid logs watch fail due to container creating state
+				return ""
+			}
+		}
+
+		if len(pod.Spec.Containers) > 1 {
+			options.Container = pod.Spec.Containers[0].Name
+		}
+
+		return Logs(t, ctx, ns, pod.Name, options)()
+	}
+}
+
+func OperatorLogs(t *testing.T, ctx context.Context, ns string) func() string {
+	return func() string {
+		pod := OperatorPod(t, ctx, ns)()
+		if pod == nil {
+			return ""
+		}
+
+		options := corev1.PodLogOptions{
+			TailLines: ptr.To(int64(200)),
 		}
 
 		for _, container := range pod.Status.ContainerStatuses {
@@ -442,7 +469,7 @@ func IntegrationLogs(t *testing.T, ctx context.Context, ns, name string) func()
 func TailedLogs(t *testing.T, ctx context.Context, ns, name string, numLines int64) func() string {
 	return func() string {
 		options := corev1.PodLogOptions{
-			TailLines: pointer.Int64(numLines),
+			TailLines: ptr.To(numLines),
 		}
 
 		return Logs(t, ctx, ns, name, options)()
@@ -546,6 +573,10 @@ func IntegrationPod(t *testing.T, ctx context.Context, ns string, name string) f
 		if len(pods) == 0 {
 			return nil
 		}
+
+		sort.SliceStable(pods, func(i, j int) bool {
+			return pods[i].GetCreationTimestamp().Time.After(pods[j].GetCreationTimestamp().Time)
+		})
 		return &pods[0]
 	}
 }
@@ -808,16 +839,6 @@ func Service(t *testing.T, ctx context.Context, ns string, name string) func() *
 	}
 }
 
-func ServiceType(t *testing.T, ctx context.Context, ns string, name string) func() corev1.ServiceType {
-	return func() corev1.ServiceType {
-		svc := Service(t, ctx, ns, name)()
-		if svc == nil {
-			return ""
-		}
-		return svc.Spec.Type
-	}
-}
-
 // ServicesByType Find the service in the given namespace with the given type
 func ServicesByType(t *testing.T, ctx context.Context, ns string, svcType corev1.ServiceType) func() []corev1.Service {
 	return func() []corev1.Service {
@@ -1291,18 +1312,10 @@ func KitWithPhase(phase v1.IntegrationKitPhase) KitFilter {
 	}
 }
 
-func KitWithVersion(version string) KitFilter {
+func KitWithRuntimeVersion(version string) KitFilter {
 	return &kitFilter{
 		filter: func(kit *v1.IntegrationKit) bool {
-			return kit.Status.Version == version
-		},
-	}
-}
-
-func KitWithVersionPrefix(versionPrefix string) KitFilter {
-	return &kitFilter{
-		filter: func(kit *v1.IntegrationKit) bool {
-			return strings.HasPrefix(kit.Status.Version, versionPrefix)
+			return kit.Status.RuntimeVersion == version
 		},
 	}
 }
@@ -1578,8 +1591,8 @@ func CreatePlainTextConfigmapWithOwnerRefWithLabels(t *testing.T, ctx context.Co
 				Kind:               "Integration",
 				Name:               orname,
 				UID:                uid,
-				Controller:         pointer.Bool(true),
-				BlockOwnerDeletion: pointer.Bool(true),
+				Controller:         ptr.To(true),
+				BlockOwnerDeletion: ptr.To(true),
 			},
 			},
 			Labels: labels,
@@ -1761,26 +1774,6 @@ func KnativeService(t *testing.T, ctx context.Context, ns string, name string) f
 		return &answer
 	}
 }
-func DeploymentWithIntegrationLabel(t *testing.T, ctx context.Context, ns string, label string) func() *appsv1.Deployment {
-	return func() *appsv1.Deployment {
-		lst := appsv1.DeploymentList{
-			TypeMeta: metav1.TypeMeta{
-				Kind:       "Deployment",
-				APIVersion: appsv1.SchemeGroupVersion.String(),
-			},
-		}
-		if err := TestClient(t).List(ctx, &lst, ctrl.InNamespace(ns), ctrl.MatchingLabels{v1.IntegrationLabel: label}); err != nil && k8serrors.IsNotFound(err) {
-			return nil
-		} else if err != nil {
-			log.Errorf(err, "Error while retrieving deployment %s", label)
-			return nil
-		}
-		if len(lst.Items) == 0 {
-			return nil
-		}
-		return &lst.Items[0]
-	}
-}
 
 func Deployment(t *testing.T, ctx context.Context, ns string, name string) func() *appsv1.Deployment {
 	return func() *appsv1.Deployment {
@@ -1827,6 +1820,12 @@ func DeploymentCondition(t *testing.T, ctx context.Context, ns string, name stri
 	}
 }
 
+func DeploymentUID(t *testing.T, ctx context.Context, ns string, name string) func() string {
+	return func() string {
+		return string(Deployment(t, ctx, ns, name)().GetUID())
+	}
+}
+
 func Build(t *testing.T, ctx context.Context, ns, name string) func() *v1.Build {
 	return func() *v1.Build {
 		build := v1.NewBuild(ns, name)
@@ -2088,8 +2087,9 @@ func DeletePlatform(t *testing.T, ctx context.Context, ns string) func() bool {
 		}
 		if err := TestClient(t).Delete(ctx, pl); err != nil {
 			log.Error(err, "Got error while deleting the platform")
+			return false
 		}
-		return false
+		return true
 	}
 }
 
@@ -2110,6 +2110,10 @@ func UpdatePlatform(t *testing.T, ctx context.Context, ns string, upd func(ip *v
 	return TestClient(t).Patch(ctx, target, ctrl.RawPatch(types.MergePatchType, p))
 }
 
+func CreateIntegrationPlatform(t *testing.T, ctx context.Context, ip *v1.IntegrationPlatform) error {
+	return TestClient(t).Create(ctx, ip)
+}
+
 func PlatformVersion(t *testing.T, ctx context.Context, ns string) func() string {
 	return func() string {
 		p := Platform(t, ctx, ns)()
@@ -2120,6 +2124,16 @@ func PlatformVersion(t *testing.T, ctx context.Context, ns string) func() string
 	}
 }
 
+func PlatformRuntimeVersion(t *testing.T, ctx context.Context, ns string) func() string {
+	return func() string {
+		p := Platform(t, ctx, ns)()
+		if p == nil {
+			return ""
+		}
+		return p.Status.Build.RuntimeVersion
+	}
+}
+
 func PlatformPhase(t *testing.T, ctx context.Context, ns string) func() v1.IntegrationPlatformPhase {
 	return func() v1.IntegrationPlatformPhase {
 		p := Platform(t, ctx, ns)()
@@ -2210,17 +2224,6 @@ func AssignPlatformToOperator(t *testing.T, ctx context.Context, ns, operator st
 	return TestClient(t).Update(ctx, pl)
 }
 
-func GetExpectedCRDs(releaseVersion string) int {
-	switch releaseVersion {
-	case "2.2.0":
-		return 8
-	case defaults.Version:
-		return ExpectedCRDs
-	}
-
-	return ExpectedCRDs
-}
-
 func CRDs(t *testing.T) func() []metav1.APIResource {
 	return func() []metav1.APIResource {
 
@@ -2673,10 +2676,12 @@ func CreateKameletWithID(t *testing.T, operatorID string, ctx context.Context, n
 				Labels:    labels,
 			},
 			Spec: v1.KameletSpec{
-				Definition: &v1.JSONSchemaProps{
-					Properties: properties,
+				KameletSpecBase: v1.KameletSpecBase{
+					Definition: &v1.JSONSchemaProps{
+						Properties: properties,
+					},
+					Template: asTemplate(t, template),
 				},
-				Template: asTemplate(t, template),
 			},
 		}
 
