@@ -25,6 +25,9 @@ import (
 
 func init() {
 	// Register the types with the Scheme so the components can map objects to GroupVersionKinds and back
-	AddToSchemes = append(AddToSchemes, operatorsv1.AddToScheme, operatorsv1alpha1.AddToScheme, operatorsv1alpha2.AddToScheme)
-
+	AddToSchemes = append(AddToSchemes,
+		operatorsv1.AddToScheme,
+		operatorsv1alpha1.AddToScheme,
+		operatorsv1alpha2.AddToScheme,
+	)
 }
