@@ -37,6 +37,7 @@ import (
 // +kubebuilder:printcolumn:name="Ready",type=string,JSONPath=`.status.conditions[?(@.type=="Ready")].status`,description="The integration readiness"
 // +kubebuilder:printcolumn:name="Runtime Provider",type=string,JSONPath=`.status.runtimeProvider`,description="The runtime version"
 // +kubebuilder:printcolumn:name="Runtime Version",type=string,JSONPath=`.status.runtimeVersion`,description="The runtime provider"
+// +kubebuilder:printcolumn:name="Catalog Version",type=string,JSONPath=`.status.catalog.version`,description="The catalog version"
 // +kubebuilder:printcolumn:name="Kit",type=string,JSONPath=`.status.integrationKit.name`,description="The integration kit"
 // +kubebuilder:printcolumn:name="Replicas",type=integer,JSONPath=`.status.replicas`,description="The number of pods"
 
@@ -96,6 +97,8 @@ type IntegrationStatus struct {
 	Dependencies []string `json:"dependencies,omitempty"`
 	// the profile needed to run this Integration
 	Profile TraitProfile `json:"profile,omitempty"`
+	// the traits executed for the Integration
+	Traits *Traits `json:"traits,omitempty"`
 	// the reference of the `IntegrationKit` which is used for this Integration
 	IntegrationKit *corev1.ObjectReference `json:"integrationKit,omitempty"`
 	// The IntegrationPlatform watching this Integration
@@ -106,6 +109,8 @@ type IntegrationStatus struct {
 	RuntimeVersion string `json:"runtimeVersion,omitempty"`
 	// the runtime provider targeted for this Integration
 	RuntimeProvider RuntimeProvider `json:"runtimeProvider,omitempty"`
+	// the catalog used to build/operate the Integration.
+	Catalog *Catalog `json:"catalog,omitempty"`
 	// Deprecated:
 	// a list of configuration specification
 	Configuration []ConfigurationSpec `json:"configuration,omitempty"`
@@ -156,6 +161,8 @@ const (
 	IntegrationPhaseRunning IntegrationPhase = "Running"
 	// IntegrationPhaseError --.
 	IntegrationPhaseError IntegrationPhase = "Error"
+	// IntegrationPhaseUnknown --.
+	IntegrationPhaseUnknown IntegrationPhase = "Unknown"
 
 	// IntegrationConditionReady --.
 	IntegrationConditionReady IntegrationConditionType = "Ready"
