@@ -23,19 +23,18 @@ import corev1 "k8s.io/api/core/v1"
 //
 // It also provides configuration for Services associated to the container.
 //
-// +camel-k:trait=container
-// nolint: tagliatelle
+// +camel-k:trait=container.
 type ContainerTrait struct {
 	PlatformBaseTrait `property:",squash" json:",inline"`
 	// To automatically enable the trait
 	Auto *bool `property:"auto" json:"auto,omitempty"`
-	// The minimum amount of CPU required.
+	// The minimum amount of CPU required (default 125 millicores).
 	RequestCPU string `property:"request-cpu" json:"requestCPU,omitempty"`
-	// The minimum amount of memory required.
+	// The minimum amount of memory required (default 128 Mi).
 	RequestMemory string `property:"request-memory" json:"requestMemory,omitempty"`
-	// The maximum amount of CPU required.
+	// The maximum amount of CPU to be provided (default 500 millicores).
 	LimitCPU string `property:"limit-cpu" json:"limitCPU,omitempty"`
-	// The maximum amount of memory required.
+	// The maximum amount of memory to be provided (default 512 Mi).
 	LimitMemory string `property:"limit-memory" json:"limitMemory,omitempty"`
 	// Can be used to enable/disable exposure via kubernetes Service.
 	Expose *bool `property:"expose" json:"expose,omitempty"`
@@ -56,4 +55,17 @@ type ContainerTrait struct {
 	// The pull policy: Always|Never|IfNotPresent
 	// +kubebuilder:validation:Enum=Always;Never;IfNotPresent
 	ImagePullPolicy corev1.PullPolicy `property:"image-pull-policy" json:"imagePullPolicy,omitempty"`
+	// Security Context RunAsUser configuration (default none): this value is automatically retrieved in Openshift clusters when not explicitly set.
+	RunAsUser *int64 `property:"run-as-user" json:"runAsUser,omitempty"`
+	// Security Context RunAsNonRoot configuration (default false).
+	RunAsNonRoot *bool `property:"run-as-non-root" json:"runAsNonRoot,omitempty"`
+	// Security Context SeccompProfileType configuration (default RuntimeDefault).
+	// +kubebuilder:validation:Enum=Unconfined;RuntimeDefault
+	SeccompProfileType corev1.SeccompProfileType `property:"seccomp-profile-type" json:"seccompProfileType,omitempty"`
+	// Security Context AllowPrivilegeEscalation configuration (default false).
+	AllowPrivilegeEscalation *bool `property:"allow-privilege-escalation" json:"allowPrivilegeEscalation,omitempty"`
+	// Security Context Capabilities Drop configuration (default ALL).
+	CapabilitiesDrop []corev1.Capability `property:"capabilities-drop" json:"capabilitiesDrop,omitempty"`
+	// Security Context Capabilities Add configuration (default none).
+	CapabilitiesAdd []corev1.Capability `property:"capabilities-add" json:"capabilitiesAdd,omitempty"`
 }
