@@ -23,6 +23,7 @@ import (
 	"os"
 	"path/filepath"
 	"strings"
+	"time"
 
 	"github.com/apache/camel-k/v2/pkg/util/boolean"
 
@@ -32,11 +33,11 @@ import (
 	"github.com/apache/camel-k/v2/pkg/util/camel"
 	"github.com/apache/camel-k/v2/pkg/util/defaults"
 	"github.com/apache/camel-k/v2/pkg/util/digest"
-	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
 	"github.com/apache/camel-k/v2/pkg/util/maven"
-	corev1 "k8s.io/api/core/v1"
 )
 
+const projectModePerm = 0600
+
 func init() {
 	registerSteps(Quarkus)
 
@@ -65,47 +66,34 @@ var Quarkus = quarkusSteps{
 	ComputeQuarkusDependencies: NewStep(ProjectBuildPhase+1, computeQuarkusDependencies),
 }
 
-func resolveBuildSources(ctx *builderContext) ([]v1.SourceSpec, error) {
-	resources := kubernetes.NewCollection()
-	return kubernetes.ResolveSources(ctx.Build.Sources, func(name string) (*corev1.ConfigMap, error) {
-		// the config map could be part of the resources created
-		// by traits
-		cm := resources.GetConfigMap(func(m *corev1.ConfigMap) bool {
-			return m.Name == name
-		})
-
-		if cm != nil {
-			return cm, nil
-		}
-
-		return kubernetes.GetConfigMap(ctx.C, ctx.Client, name, ctx.Namespace)
-	})
-}
-
 func prepareProjectWithSources(ctx *builderContext) error {
-	sources, err := resolveBuildSources(ctx)
-	if err != nil {
-		return err
-	}
 	sourcesPath := filepath.Join(ctx.Path, "maven", "src", "main", "resources", "routes")
 	if err := os.MkdirAll(sourcesPath, os.ModePerm); err != nil {
 		return fmt.Errorf("failure while creating resource folder: %w", err)
 	}
 
 	sourceList := ""
-	for _, source := range sources {
+	for _, source := range ctx.Build.Sources {
 		if sourceList != "" {
 			sourceList += ","
 		}
 		sourceList += "classpath:routes/" + source.Name
-		if err := os.WriteFile(filepath.Join(sourcesPath, source.Name), []byte(source.Content), os.ModePerm); err != nil {
+		if err := os.WriteFile(
+			filepath.Join(sourcesPath, source.Name),
+			[]byte(source.Content),
+			projectModePerm,
+		); err != nil {
 			return fmt.Errorf("failure while writing %s: %w", source.Name, err)
 		}
 	}
 
 	if sourceList != "" {
 		routesIncludedPattern := "camel.main.routes-include-pattern = " + sourceList
-		if err := os.WriteFile(filepath.Join(filepath.Dir(sourcesPath), "application.properties"), []byte(routesIncludedPattern), os.ModePerm); err != nil {
+		if err := os.WriteFile(
+			filepath.Join(filepath.Dir(sourcesPath), "application.properties"),
+			[]byte(routesIncludedPattern),
+			projectModePerm,
+		); err != nil {
 			return fmt.Errorf("failure while writing the configuration application.properties: %w", err)
 		}
 	}
@@ -152,7 +140,8 @@ func generateQuarkusProjectCommon(runtimeVersion string, quarkusPlatformVersion
 
 	// set fast-jar packaging by default, since it gives some startup time improvements
 	p.Properties.Add("quarkus.package.type", "fast-jar")
-
+	// Reproducible builds: https://maven.apache.org/guides/mini/guide-reproducible-builds.html
+	p.Properties.Add("project.build.outputTimestamp", time.Now().Format(time.RFC3339))
 	// DependencyManagement
 	p.DependencyManagement.Dependencies = append(p.DependencyManagement.Dependencies,
 		maven.Dependency{
