@@ -22,6 +22,7 @@ import (
 
 	"github.com/spf13/cobra"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	"github.com/apache/camel-k/v2/pkg/util/test"
@@ -35,7 +36,7 @@ func initializeInstallCmdOptions(t *testing.T) (*installCmdOptions, *cobra.Comma
 
 	options, rootCmd := kamelTestPreAddCommandInit()
 	installCmdOptions := addTestInstallCmd(*options, rootCmd)
-	kamelTestPostAddCommandInit(t, rootCmd)
+	kamelTestPostAddCommandInit(t, rootCmd, options)
 
 	return installCmdOptions, rootCmd, *options
 }
@@ -57,18 +58,18 @@ func addTestInstallCmd(options RootCmdOptions, rootCmd *cobra.Command) *installC
 func TestInstallNoFlag(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	// Check default expected values
-	assert.Equal(t, false, installCmdOptions.Wait)
-	assert.Equal(t, false, installCmdOptions.ClusterSetupOnly)
-	assert.Equal(t, false, installCmdOptions.SkipOperatorSetup)
-	assert.Equal(t, false, installCmdOptions.SkipClusterSetup)
-	assert.Equal(t, false, installCmdOptions.SkipDefaultKameletsSetup)
-	assert.Equal(t, false, installCmdOptions.ExampleSetup)
-	assert.Equal(t, false, installCmdOptions.Global)
-	assert.Equal(t, false, installCmdOptions.Save)
-	assert.Equal(t, false, installCmdOptions.Force)
-	assert.Equal(t, true, installCmdOptions.Olm)
+	assert.False(t, installCmdOptions.Wait)
+	assert.False(t, installCmdOptions.ClusterSetupOnly)
+	assert.False(t, installCmdOptions.SkipOperatorSetup)
+	assert.False(t, installCmdOptions.SkipClusterSetup)
+	assert.False(t, installCmdOptions.SkipDefaultKameletsSetup)
+	assert.False(t, installCmdOptions.ExampleSetup)
+	assert.False(t, installCmdOptions.Global)
+	assert.False(t, installCmdOptions.Save)
+	assert.False(t, installCmdOptions.Force)
+	assert.True(t, installCmdOptions.Olm)
 	assert.Equal(t, "", installCmdOptions.olmOptions.OperatorName)
 	assert.Equal(t, "", installCmdOptions.olmOptions.Package)
 	assert.Equal(t, "", installCmdOptions.olmOptions.Channel)
@@ -76,105 +77,97 @@ func TestInstallNoFlag(t *testing.T) {
 	assert.Equal(t, "", installCmdOptions.olmOptions.SourceNamespace)
 	assert.Equal(t, "", installCmdOptions.olmOptions.GlobalNamespace)
 	assert.Equal(t, int32(8081), installCmdOptions.HealthPort)
-	assert.Equal(t, false, installCmdOptions.Monitoring)
+	assert.False(t, installCmdOptions.Monitoring)
 	assert.Equal(t, int32(8080), installCmdOptions.MonitoringPort)
 }
 
 func TestInstallNonExistingFlag(t *testing.T) {
 	_, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall, "--nonExistingFlag")
-	assert.NotNil(t, err)
+	require.Error(t, err)
 }
 
 func TestInstallBaseImageFlag(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall, "--base-image", "someString")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "someString", installCmdOptions.BaseImage)
 }
 
 func TestInstallBuildPublishStrategyFlag(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall, "--build-publish-strategy", "someString")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "someString", installCmdOptions.BuildPublishStrategy)
 }
 
 func TestInstallBuildStrategyFlag(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall, "--build-strategy", "someString")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "someString", installCmdOptions.BuildStrategy)
 }
 
 func TestInstallBuildOrderStrategyFlag(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall, "--build-order-strategy", "someString")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "someString", installCmdOptions.BuildOrderStrategy)
 }
 
 func TestInstallBuildTimeoutFlag(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall, "--build-timeout", "10")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "10", installCmdOptions.BuildTimeout)
 }
 
 func TestInstallClusterSetupFlag(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall, "--cluster-setup")
-	assert.Nil(t, err)
-	assert.Equal(t, true, installCmdOptions.ClusterSetupOnly)
+	require.NoError(t, err)
+	assert.True(t, installCmdOptions.ClusterSetupOnly)
 }
 
 func TestInstallClusterTypeFlag(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall, "--cluster-type", "Kubernetes")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "Kubernetes", installCmdOptions.ClusterType)
 }
 
 func TestInstallExampleFlag(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall, "--example")
-	assert.Nil(t, err)
-	assert.Equal(t, true, installCmdOptions.ExampleSetup)
+	require.NoError(t, err)
+	assert.True(t, installCmdOptions.ExampleSetup)
 }
 
 func TestInstallForceFlag(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall, "--force")
-	assert.Nil(t, err)
-	assert.Equal(t, true, installCmdOptions.Force)
+	require.NoError(t, err)
+	assert.True(t, installCmdOptions.Force)
 }
 
 func TestInstallGlobalFlag(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall, "--global")
-	assert.Nil(t, err)
-	assert.Equal(t, true, installCmdOptions.Global)
+	require.NoError(t, err)
+	assert.True(t, installCmdOptions.Global)
 }
 
 func TestInstallHealthFlag(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall, "--health-port", "7777")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, int32(7777), installCmdOptions.HealthPort)
 }
 
-func TestInstallBuildPublishStrategyOptions(t *testing.T) {
-	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
-	_, err := test.ExecuteCommand(rootCmd, cmdInstall, "--build-publish-strategy-option", "foo1=bar1", "--build-publish-strategy-option", "foo2=bar2")
-	assert.Nil(t, err)
-	assert.Equal(t, "foo1=bar1", installCmdOptions.BuildPublishStrategyOptions[0])
-	assert.Equal(t, "foo2=bar2", installCmdOptions.BuildPublishStrategyOptions[1])
-}
-
 func TestInstallLocalRepositoryFlag(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall, "--maven-local-repository", "someString")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "someString", installCmdOptions.MavenLocalRepository)
 }
 
@@ -183,7 +176,7 @@ func TestInstallMavenRepositoryFlag(t *testing.T) {
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall,
 		"--maven-repository", "someString1",
 		"--maven-repository", "someString2")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "someString1", installCmdOptions.MavenRepositories[0])
 	assert.Equal(t, "someString2", installCmdOptions.MavenRepositories[1])
 }
@@ -191,7 +184,7 @@ func TestInstallMavenRepositoryFlag(t *testing.T) {
 func TestInstallMavenSettingsFlag(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall, "--maven-settings", "someString")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "someString", installCmdOptions.MavenSettings)
 }
 
@@ -200,16 +193,16 @@ func TestInstallMonitoringFlag(t *testing.T) {
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall,
 		"--monitoring",
 		"--monitoring-port", "7777")
-	assert.Nil(t, err)
-	assert.Equal(t, true, installCmdOptions.Monitoring)
+	require.NoError(t, err)
+	assert.True(t, installCmdOptions.Monitoring)
 	assert.Equal(t, int32(7777), installCmdOptions.MonitoringPort)
 }
 
 func TestInstallOlmFalseFlag(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall, "--olm=false")
-	assert.Nil(t, err)
-	assert.Equal(t, false, installCmdOptions.Olm)
+	require.NoError(t, err)
+	assert.False(t, installCmdOptions.Olm)
 }
 
 func TestInstallOlmTrueNonDefaultFlag(t *testing.T) {
@@ -222,8 +215,8 @@ func TestInstallOlmTrueNonDefaultFlag(t *testing.T) {
 		"--olm-source", "olmSource",
 		"--olm-source-namespace", "olmSourceNamespace",
 		"--olm-starting-csv", "olmStartingCSV")
-	assert.Nil(t, err)
-	assert.Equal(t, true, installCmdOptions.Olm)
+	require.NoError(t, err)
+	assert.True(t, installCmdOptions.Olm)
 	assert.Equal(t, "olmChannel", installCmdOptions.olmOptions.Channel)
 	assert.Equal(t, "olmGlobalNamespace", installCmdOptions.olmOptions.GlobalNamespace)
 	assert.Equal(t, "olmOperatorName", installCmdOptions.olmOptions.OperatorName)
@@ -236,21 +229,21 @@ func TestInstallOlmTrueNonDefaultFlag(t *testing.T) {
 func TestInstallOperatorImageFlag(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall, "--operator-image", "someString")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "someString", installCmdOptions.OperatorImage)
 }
 
 func TestInstallOperatorImagePullPolicyFlag(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall, "--operator-image-pull-policy", "someString")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "someString", installCmdOptions.OperatorImagePullPolicy)
 }
 
 func TestInstallOutputFlag(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall, "--output", "yaml")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "yaml", installCmdOptions.OutputFormat)
 }
 
@@ -259,7 +252,7 @@ func TestInstallPropertyFlag(t *testing.T) {
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall,
 		"--maven-property", "someString1",
 		"--maven-property", "someString2")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "someString1", installCmdOptions.MavenProperties[0])
 	assert.Equal(t, "someString2", installCmdOptions.MavenProperties[1])
 }
@@ -271,10 +264,10 @@ func TestInstallRegistryFlag(t *testing.T) {
 		"--organization", "organization",
 		"--registry-insecure",
 		"--registry-secret", "secret")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "registry", installCmdOptions.registry.Address)
 	assert.Equal(t, "organization", installCmdOptions.registry.Organization)
-	assert.Equal(t, true, installCmdOptions.registry.Insecure)
+	assert.True(t, installCmdOptions.registry.Insecure)
 	assert.Equal(t, "secret", installCmdOptions.registry.Secret)
 }
 
@@ -284,7 +277,7 @@ func TestInstallRegistryWithAuthFlag(t *testing.T) {
 		"--registry-auth-password", "authPassword",
 		"--registry-auth-server", "authServer",
 		"--registry-auth-username", "authUsername")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "authPassword", installCmdOptions.registryAuth.Password)
 	assert.Equal(t, "authServer", installCmdOptions.registryAuth.Server)
 	assert.Equal(t, "authUsername", installCmdOptions.registryAuth.Username)
@@ -293,57 +286,57 @@ func TestInstallRegistryWithAuthFlag(t *testing.T) {
 func TestInstallRuntimeVersionFlag(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall, "--runtime-version", "1.3.0")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "1.3.0", installCmdOptions.RuntimeVersion)
 }
 
 func TestInstallSaveFlag(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall, "--save")
-	assert.Nil(t, err)
-	assert.Equal(t, true, installCmdOptions.Save)
+	require.NoError(t, err)
+	assert.True(t, installCmdOptions.Save)
 }
 
 func TestInstallSkipClusterSetupFlag(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall, "--skip-cluster-setup")
-	assert.Nil(t, err)
-	assert.Equal(t, true, installCmdOptions.SkipClusterSetup)
+	require.NoError(t, err)
+	assert.True(t, installCmdOptions.SkipClusterSetup)
 }
 
 func TestInstallSkipOperatorSetupFlag(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall, "--skip-operator-setup")
-	assert.Nil(t, err)
-	assert.Equal(t, true, installCmdOptions.SkipOperatorSetup)
+	require.NoError(t, err)
+	assert.True(t, installCmdOptions.SkipOperatorSetup)
 }
 
 func TestInstallSkipRegistrySetupFlag(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall, "--skip-registry-setup")
-	assert.Nil(t, err)
-	assert.Equal(t, true, installCmdOptions.SkipRegistrySetup)
+	require.NoError(t, err)
+	assert.True(t, installCmdOptions.SkipRegistrySetup)
 }
 
 func TestInstallSkipDefaultKameletsSetupFlag(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall, "--skip-default-kamelets-setup")
-	assert.Nil(t, err)
-	assert.Equal(t, true, installCmdOptions.SkipDefaultKameletsSetup)
+	require.NoError(t, err)
+	assert.True(t, installCmdOptions.SkipDefaultKameletsSetup)
 }
 
 func TestInstallTraitProfileFlag(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall, "--trait-profile", "someString")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "someString", installCmdOptions.TraitProfile)
 }
 
 func TestInstallWaitFlag(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall, "--wait")
-	assert.Nil(t, err)
-	assert.Equal(t, true, installCmdOptions.Wait)
+	require.NoError(t, err)
+	assert.True(t, installCmdOptions.Wait)
 }
 
 func TestDecodeMavenSettings(t *testing.T) {
@@ -352,35 +345,37 @@ func TestDecodeMavenSettings(t *testing.T) {
 
 	// ConfigMap
 	val, err = decodeMavenSettings("configmap:maven-settings/s.xml")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Nil(t, val.SecretKeyRef)
 	assert.Equal(t, "maven-settings", val.ConfigMapKeyRef.Name)
 	assert.Equal(t, "s.xml", val.ConfigMapKeyRef.Key)
 
 	val, err = decodeMavenSettings("configmap:maven-settings")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Nil(t, val.SecretKeyRef)
 	assert.Equal(t, "maven-settings", val.ConfigMapKeyRef.Name)
-	assert.Empty(t, val.ConfigMapKeyRef.Key)
+	// Default name
+	assert.Equal(t, "settings.xml", val.ConfigMapKeyRef.Key)
 
 	// Secrets
 	val, err = decodeMavenSettings("secret:maven-settings-secret/s.xml")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Nil(t, val.ConfigMapKeyRef)
 	assert.Equal(t, "maven-settings-secret", val.SecretKeyRef.Name)
 	assert.Equal(t, "s.xml", val.SecretKeyRef.Key)
 
 	val, err = decodeMavenSettings("secret:maven-settings-secret")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Nil(t, val.ConfigMapKeyRef)
 	assert.Equal(t, "maven-settings-secret", val.SecretKeyRef.Name)
-	assert.Empty(t, val.SecretKeyRef.Key)
+	// Default name
+	assert.Equal(t, "settings.xml", val.SecretKeyRef.Key)
 
 	// Errors
 	_, err = decodeMavenSettings("something:maven-settings-secret/s.xml")
-	assert.NotNil(t, err)
+	require.Error(t, err)
 	_, err = decodeMavenSettings("secret")
-	assert.NotNil(t, err)
+	require.Error(t, err)
 }
 
 func TestInstallTolerationFlag(t *testing.T) {
@@ -388,7 +383,7 @@ func TestInstallTolerationFlag(t *testing.T) {
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall,
 		"--toleration", "key1=value1:NoSchedule",
 		"--toleration", "key2=value2:NoExecute")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "key1=value1:NoSchedule", installCmdOptions.Tolerations[0])
 	assert.Equal(t, "key2=value2:NoExecute", installCmdOptions.Tolerations[1])
 }
@@ -397,69 +392,73 @@ func TestInstallMavenExtension(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall,
 		"--maven-extension", "fi.yle.tools:aws-maven:1.4.2")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "fi.yle.tools:aws-maven:1.4.2", installCmdOptions.MavenExtensions[0])
 }
 
 func TestInstallInfoLogging(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall)
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "info", installCmdOptions.LogLevel)
 }
 
 func TestInstallInfoLogging1(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall, "-z", "0")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "0", installCmdOptions.LogLevel)
 }
 
 func TestInstallInfoLogging2(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall, "--log-level", "0")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "0", installCmdOptions.LogLevel)
 }
 
 func TestInstallInfoLogging3(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall, "-z", "info")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "info", installCmdOptions.LogLevel)
 }
 
 func TestInstallInfoLogging4(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall, "--log-level", "info")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "info", installCmdOptions.LogLevel)
 }
 
 func TestInstallDebugLogging1(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall, "-z", "1")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "1", installCmdOptions.LogLevel)
 }
 
 func TestInstallDebugLogging2(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall, "--log-level", "1")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "1", installCmdOptions.LogLevel)
 }
 
 func TestInstallDebugLogging3(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall, "-z", "debug")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "debug", installCmdOptions.LogLevel)
 }
 
 func TestInstallDebugLogging4(t *testing.T) {
 	installCmdOptions, rootCmd, _ := initializeInstallCmdOptions(t)
 	_, err := test.ExecuteCommand(rootCmd, cmdInstall, "--log-level", "debug")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "debug", installCmdOptions.LogLevel)
 }
+
+func decodeMavenSettings(mavenSettings string) (v1.ValueSource, error) {
+	return v1.DecodeValueSource(mavenSettings, "settings.xml", "illegal maven setting definition, syntax: configmap|secret:resource-name[/settings path]")
+}
