@@ -22,15 +22,16 @@ import (
 	"testing"
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
+	"github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
 	"github.com/apache/camel-k/v2/pkg/platform"
 	"github.com/apache/camel-k/v2/pkg/util/defaults"
-	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
 	"github.com/apache/camel-k/v2/pkg/util/test"
 	"github.com/spf13/cobra"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/runtime"
+	"k8s.io/utils/ptr"
 )
 
 const cmdPromote = "promote"
@@ -95,34 +96,17 @@ func TestIntegrationDryRun(t *testing.T) {
 	assert.Equal(t, "yaml", promoteCmdOptions.OutputFormat)
 	require.NoError(t, err)
 	assert.Equal(t, `apiVersion: camel.apache.org/v1
-kind: IntegrationKit
-metadata:
-  creationTimestamp: null
-  labels:
-    camel.apache.org/cloned.from.kind: IntegrationKit
-    camel.apache.org/cloned.from.name: my-it-test-kit
-    camel.apache.org/cloned.from.namespace: default
-    camel.apache.org/cloned.from.version: "999"
-    camel.apache.org/kit.type: external
-  name: my-it-test-kit
-  namespace: prod-namespace
-spec:
-  image: my-special-image
-  traits: {}
-status: {}
----
-apiVersion: camel.apache.org/v1
 kind: Integration
 metadata:
   creationTimestamp: null
   name: my-it-test
   namespace: prod-namespace
 spec:
-  integrationKit:
-    kind: IntegrationKit
-    name: my-it-test-kit
-    namespace: prod-namespace
   traits:
+    camel:
+      runtimeVersion: 1.2.3
+    container:
+      image: my-special-image
     jvm:
       classpath: /path/to/artifact-1/*:/path/to/artifact-2/*
 status: {}
@@ -139,6 +123,7 @@ func nominalIntegration(name string) (v1.Integration, v1.IntegrationKit) {
 			{Target: "/path/to/artifact-1/a-1.jar"},
 			{Target: "/path/to/artifact-2/a-2.jar"},
 		},
+		RuntimeVersion: "1.2.3",
 	}
 	it.Status.IntegrationKit = &corev1.ObjectReference{
 		Namespace: ik.Namespace,
@@ -167,37 +152,16 @@ func TestPipeDryRun(t *testing.T) {
 	assert.Equal(t, "yaml", promoteCmdOptions.OutputFormat)
 	require.NoError(t, err)
 	assert.Equal(t, `apiVersion: camel.apache.org/v1
-kind: IntegrationKit
-metadata:
-  creationTimestamp: null
-  labels:
-    camel.apache.org/cloned.from.kind: IntegrationKit
-    camel.apache.org/cloned.from.name: my-kb-test-kit
-    camel.apache.org/cloned.from.namespace: default
-    camel.apache.org/cloned.from.version: "999"
-    camel.apache.org/kit.type: external
-  name: my-kb-test-kit
-  namespace: prod-namespace
-spec:
-  image: my-special-image
-  traits: {}
-status: {}
----
-apiVersion: camel.apache.org/v1
 kind: Pipe
 metadata:
+  annotations:
+    trait.camel.apache.org/camel.runtime-version: 1.2.3
+    trait.camel.apache.org/container.image: my-special-image
+    trait.camel.apache.org/jvm.classpath: /path/to/artifact-1/*:/path/to/artifact-2/*
   creationTimestamp: null
   name: my-kb-test
   namespace: prod-namespace
 spec:
-  integration:
-    integrationKit:
-      kind: IntegrationKit
-      name: my-kb-test-kit
-      namespace: prod-namespace
-    traits:
-      jvm:
-        classpath: /path/to/artifact-1/*:/path/to/artifact-2/*
   sink: {}
   source: {}
 status: {}
@@ -241,23 +205,6 @@ func TestIntegrationWithMetadataDryRun(t *testing.T) {
 	assert.Equal(t, "yaml", promoteCmdOptions.OutputFormat)
 	require.NoError(t, err)
 	assert.Equal(t, `apiVersion: camel.apache.org/v1
-kind: IntegrationKit
-metadata:
-  creationTimestamp: null
-  labels:
-    camel.apache.org/cloned.from.kind: IntegrationKit
-    camel.apache.org/cloned.from.name: my-it-test-kit
-    camel.apache.org/cloned.from.namespace: default
-    camel.apache.org/cloned.from.version: "999"
-    camel.apache.org/kit.type: external
-  name: my-it-test-kit
-  namespace: prod-namespace
-spec:
-  image: my-special-image
-  traits: {}
-status: {}
----
-apiVersion: camel.apache.org/v1
 kind: Integration
 metadata:
   annotations:
@@ -268,11 +215,11 @@ metadata:
   name: my-it-test
   namespace: prod-namespace
 spec:
-  integrationKit:
-    kind: IntegrationKit
-    name: my-it-test-kit
-    namespace: prod-namespace
   traits:
+    camel:
+      runtimeVersion: 1.2.3
+    container:
+      image: my-special-image
     jvm:
       classpath: /path/to/artifact-1/*:/path/to/artifact-2/*
 status: {}
@@ -305,41 +252,19 @@ func TestPipeWithMetadataDryRun(t *testing.T) {
 	assert.Equal(t, "yaml", promoteCmdOptions.OutputFormat)
 	require.NoError(t, err)
 	assert.Equal(t, `apiVersion: camel.apache.org/v1
-kind: IntegrationKit
-metadata:
-  creationTimestamp: null
-  labels:
-    camel.apache.org/cloned.from.kind: IntegrationKit
-    camel.apache.org/cloned.from.name: my-kb-test-kit
-    camel.apache.org/cloned.from.namespace: default
-    camel.apache.org/cloned.from.version: "999"
-    camel.apache.org/kit.type: external
-  name: my-kb-test-kit
-  namespace: prod-namespace
-spec:
-  image: my-special-image
-  traits: {}
-status: {}
----
-apiVersion: camel.apache.org/v1
 kind: Pipe
 metadata:
   annotations:
     my-annotation: my-value
+    trait.camel.apache.org/camel.runtime-version: 1.2.3
+    trait.camel.apache.org/container.image: my-special-image
+    trait.camel.apache.org/jvm.classpath: /path/to/artifact-1/*:/path/to/artifact-2/*
   creationTimestamp: null
   labels:
     my-label: my-value
   name: my-kb-test
   namespace: prod-namespace
 spec:
-  integration:
-    integrationKit:
-      kind: IntegrationKit
-      name: my-kb-test-kit
-      namespace: prod-namespace
-    traits:
-      jvm:
-        classpath: /path/to/artifact-1/*:/path/to/artifact-2/*
   sink: {}
   source: {}
 status: {}
@@ -404,25 +329,6 @@ func TestIntegrationToOperatorId(t *testing.T) {
 	assert.Equal(t, "yaml", promoteCmdOptions.OutputFormat)
 	require.NoError(t, err)
 	assert.Equal(t, `apiVersion: camel.apache.org/v1
-kind: IntegrationKit
-metadata:
-  annotations:
-    camel.apache.org/operator.id: my-prod-operator
-  creationTimestamp: null
-  labels:
-    camel.apache.org/cloned.from.kind: IntegrationKit
-    camel.apache.org/cloned.from.name: my-it-test-kit
-    camel.apache.org/cloned.from.namespace: default
-    camel.apache.org/cloned.from.version: "999"
-    camel.apache.org/kit.type: external
-  name: my-it-test-kit
-  namespace: prod
-spec:
-  image: my-special-image
-  traits: {}
-status: {}
----
-apiVersion: camel.apache.org/v1
 kind: Integration
 metadata:
   annotations:
@@ -431,11 +337,11 @@ metadata:
   name: my-it-test
   namespace: prod
 spec:
-  integrationKit:
-    kind: IntegrationKit
-    name: my-it-test-kit
-    namespace: prod
   traits:
+    camel:
+      runtimeVersion: 1.2.3
+    container:
+      image: my-special-image
     jvm:
       classpath: /path/to/artifact-1/*:/path/to/artifact-2/*
 status: {}
@@ -449,25 +355,6 @@ status: {}
 	assert.Equal(t, "yaml", promoteCmdOptions.OutputFormat)
 	require.NoError(t, err)
 	assert.Equal(t, `apiVersion: camel.apache.org/v1
-kind: IntegrationKit
-metadata:
-  annotations:
-    camel.apache.org/operator.id: my-prod-operator
-  creationTimestamp: null
-  labels:
-    camel.apache.org/cloned.from.kind: IntegrationKit
-    camel.apache.org/cloned.from.name: my-it-test-kit
-    camel.apache.org/cloned.from.namespace: default
-    camel.apache.org/cloned.from.version: "999"
-    camel.apache.org/kit.type: external
-  name: my-it-test-kit
-  namespace: prod
-spec:
-  image: my-special-image
-  traits: {}
-status: {}
----
-apiVersion: camel.apache.org/v1
 kind: Integration
 metadata:
   annotations:
@@ -476,18 +363,18 @@ metadata:
   name: my-it-test
   namespace: prod
 spec:
-  integrationKit:
-    kind: IntegrationKit
-    name: my-it-test-kit
-    namespace: prod
   traits:
+    camel:
+      runtimeVersion: 1.2.3
+    container:
+      image: my-special-image
     jvm:
       classpath: /path/to/artifact-1/*:/path/to/artifact-2/*
 status: {}
 `, output)
 }
 
-func TestIntegrationKitWithLabels(t *testing.T) {
+func TestIntegrationWithSavedTraitsDryRun(t *testing.T) {
 	srcPlatform := v1.NewIntegrationPlatform("default", platform.DefaultPlatformName)
 	srcPlatform.Status.Version = defaults.Version
 	srcPlatform.Status.Build.RuntimeVersion = defaults.DefaultRuntimeVersion
@@ -497,11 +384,12 @@ func TestIntegrationKitWithLabels(t *testing.T) {
 	dstPlatform.Status.Build.RuntimeVersion = defaults.DefaultRuntimeVersion
 	dstPlatform.Status.Phase = v1.IntegrationPlatformPhaseReady
 	defaultIntegration, defaultKit := nominalIntegration("my-it-test")
-	defaultKit.Labels = map[string]string{
-		kubernetes.CamelCreatorLabelKind:      "Integration",
-		kubernetes.CamelCreatorLabelName:      "my-original-it-name",
-		kubernetes.CamelCreatorLabelNamespace: "my-original-it-namespace",
-		kubernetes.CamelCreatorLabelVersion:   "my-original-it-version",
+	defaultIntegration.Status.Traits = &v1.Traits{
+		Service: &trait.ServiceTrait{
+			Trait: trait.Trait{
+				Enabled: ptr.To(true),
+			},
+		},
 	}
 	srcCatalog := createTestCamelCatalog(srcPlatform)
 	dstCatalog := createTestCamelCatalog(dstPlatform)
@@ -511,36 +399,66 @@ func TestIntegrationKitWithLabels(t *testing.T) {
 	assert.Equal(t, "yaml", promoteCmdOptions.OutputFormat)
 	require.NoError(t, err)
 	assert.Equal(t, `apiVersion: camel.apache.org/v1
-kind: IntegrationKit
-metadata:
-  creationTimestamp: null
-  labels:
-    camel.apache.org/cloned.from.kind: IntegrationKit
-    camel.apache.org/cloned.from.name: my-it-test-kit
-    camel.apache.org/cloned.from.namespace: default
-    camel.apache.org/cloned.from.version: "999"
-    camel.apache.org/kit.type: external
-  name: my-it-test-kit
-  namespace: prod-namespace
-spec:
-  image: my-special-image
-  traits: {}
-status: {}
----
-apiVersion: camel.apache.org/v1
 kind: Integration
 metadata:
   creationTimestamp: null
   name: my-it-test
   namespace: prod-namespace
 spec:
-  integrationKit:
-    kind: IntegrationKit
-    name: my-it-test-kit
-    namespace: prod-namespace
   traits:
+    camel:
+      runtimeVersion: 1.2.3
+    container:
+      image: my-special-image
     jvm:
       classpath: /path/to/artifact-1/*:/path/to/artifact-2/*
+    service:
+      enabled: true
+status: {}
+`, output)
+}
+
+func TestPipeWithSavedTraitsDryRun(t *testing.T) {
+	srcPlatform := v1.NewIntegrationPlatform("default", platform.DefaultPlatformName)
+	srcPlatform.Status.Version = defaults.Version
+	srcPlatform.Status.Build.RuntimeVersion = defaults.DefaultRuntimeVersion
+	srcPlatform.Status.Phase = v1.IntegrationPlatformPhaseReady
+	dstPlatform := v1.NewIntegrationPlatform("prod-namespace", platform.DefaultPlatformName)
+	dstPlatform.Status.Version = defaults.Version
+	dstPlatform.Status.Build.RuntimeVersion = defaults.DefaultRuntimeVersion
+	dstPlatform.Status.Phase = v1.IntegrationPlatformPhaseReady
+	defaultKB := nominalPipe("my-kb-test")
+	defaultKB.Annotations = map[string]string{
+		"camel.apache.org/operator.id": "camel-k",
+		"my-annotation":                "my-value",
+	}
+	defaultKB.Labels = map[string]string{
+		"my-label": "my-value",
+	}
+	defaultIntegration, defaultKit := nominalIntegration("my-kb-test")
+	srcCatalog := createTestCamelCatalog(srcPlatform)
+	dstCatalog := createTestCamelCatalog(dstPlatform)
+
+	promoteCmdOptions, promoteCmd, _ := initializePromoteCmdOptions(t, &srcPlatform, &dstPlatform, &defaultKB, &defaultIntegration, &defaultKit, &srcCatalog, &dstCatalog)
+	output, err := test.ExecuteCommand(promoteCmd, cmdPromote, "my-kb-test", "--to", "prod-namespace", "-o", "yaml", "-n", "default")
+	assert.Equal(t, "yaml", promoteCmdOptions.OutputFormat)
+	require.NoError(t, err)
+	assert.Equal(t, `apiVersion: camel.apache.org/v1
+kind: Pipe
+metadata:
+  annotations:
+    my-annotation: my-value
+    trait.camel.apache.org/camel.runtime-version: 1.2.3
+    trait.camel.apache.org/container.image: my-special-image
+    trait.camel.apache.org/jvm.classpath: /path/to/artifact-1/*:/path/to/artifact-2/*
+  creationTimestamp: null
+  labels:
+    my-label: my-value
+  name: my-kb-test
+  namespace: prod-namespace
+spec:
+  sink: {}
+  source: {}
 status: {}
 `, output)
 }
