@@ -32,7 +32,7 @@ import (
 	"k8s.io/apimachinery/pkg/runtime/schema"
 	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/client-go/tools/record"
-	"k8s.io/utils/pointer"
+	"k8s.io/utils/ptr"
 	"sigs.k8s.io/controller-runtime/pkg/builder"
 	ctrl "sigs.k8s.io/controller-runtime/pkg/client"
 	"sigs.k8s.io/controller-runtime/pkg/event"
@@ -56,6 +56,8 @@ import (
 	utilResource "github.com/apache/camel-k/v2/pkg/util/resource"
 )
 
+const retryMonitoring = 5
+
 func Add(ctx context.Context, mgr manager.Manager, c client.Client) error {
 	err := mgr.GetFieldIndexer().IndexField(ctx, &corev1.Pod{}, "status.phase",
 		func(obj ctrl.Object) []string {
@@ -202,7 +204,7 @@ func enqueueRequestsFromConfigFunc(ctx context.Context, c client.Client, res ctr
 
 	for _, integration := range list.Items {
 		found := false
-		if integration.Spec.Traits.Mount == nil || !pointer.BoolDeref(integration.Spec.Traits.Mount.HotReload, false) {
+		if integration.Spec.Traits.Mount == nil || !ptr.Deref(integration.Spec.Traits.Mount.HotReload, false) {
 			continue
 		}
 		for _, c := range integration.Spec.Traits.Mount.Configs {
@@ -529,7 +531,7 @@ func (r *reconcileIntegration) Reconcile(ctx context.Context, request reconcile.
 	if instance.IsSynthetic() {
 		actions = append(actions, NewMonitorSyntheticAction())
 	} else {
-		actions = append(actions, NewMonitorAction())
+		actions = append(actions, NewMonitorAction(), NewMonitorUnknownAction())
 	}
 
 	for _, a := range actions {
@@ -557,6 +559,11 @@ func (r *reconcileIntegration) Reconcile(ctx context.Context, request reconcile.
 				camelevent.NotifyIntegrationError(ctx, r.client, r.recorder, &instance, newTarget, err)
 				return reconcile.Result{}, err
 			}
+
+			if newTarget.Status.Phase == v1.IntegrationPhaseUnknown {
+				// Wait for some time before trying to monitor again
+				return reconcile.Result{RequeueAfter: retryMonitoring * time.Second}, nil
+			}
 		}
 
 		// handle one action at time so the resource
