@@ -25,6 +25,7 @@ import (
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
+	"github.com/apache/camel-k/v2/pkg/client"
 
 	"github.com/apache/camel-k/v2/pkg/trait"
 	"github.com/apache/camel-k/v2/pkg/util/test"
@@ -279,7 +280,10 @@ func TestHasMatchingTraits_KitNoTraitShouldNotBePicked(t *testing.T) {
 		},
 	}
 
-	ok, err := integrationAndKitHaveSameTraits(integration, kit)
+	c, err := test.NewFakeClient(integration, kit)
+	require.NoError(t, err)
+
+	ok, err := integrationAndKitHaveSameTraits(c, integration, kit)
 	require.NoError(t, err)
 	assert.False(t, ok)
 }
@@ -326,8 +330,9 @@ func TestHasMatchingTraits_KitSameTraitShouldBePicked(t *testing.T) {
 			},
 		},
 	}
-
-	ok, err := integrationAndKitHaveSameTraits(integration, kit)
+	c, err := test.NewFakeClient(integration, kit)
+	require.NoError(t, err)
+	ok, err := integrationAndKitHaveSameTraits(c, integration, kit)
 	require.NoError(t, err)
 	assert.True(t, ok)
 }
@@ -429,12 +434,12 @@ func TestHasNotMatchingSources(t *testing.T) {
 	assert.False(t, hsm2)
 }
 
-func integrationAndKitHaveSameTraits(i1 *v1.Integration, i2 *v1.IntegrationKit) (bool, error) {
-	itOpts, err := trait.NewSpecTraitsOptionsForIntegration(i1)
+func integrationAndKitHaveSameTraits(c client.Client, i1 *v1.Integration, i2 *v1.IntegrationKit) (bool, error) {
+	itOpts, err := trait.NewSpecTraitsOptionsForIntegration(c, i1)
 	if err != nil {
 		return false, err
 	}
-	ikOpts, err := trait.NewSpecTraitsOptionsForIntegrationKit(i2)
+	ikOpts, err := trait.NewSpecTraitsOptionsForIntegrationKit(c, i2)
 	if err != nil {
 		return false, err
 	}
