@@ -19,7 +19,6 @@ package integrationplatform
 
 import (
 	"context"
-	"time"
 
 	k8serrors "k8s.io/apimachinery/pkg/api/errors"
 	"k8s.io/apimachinery/pkg/runtime"
@@ -41,10 +40,6 @@ import (
 	"github.com/apache/camel-k/v2/pkg/util/monitoring"
 )
 
-const (
-	requeueAfterDuration = 5 * time.Second
-)
-
 // Add creates a new IntegrationPlatform Controller and adds it to the Manager. The Manager will set fields
 // on the Controller and Start it when the Manager is Started.
 func Add(ctx context.Context, mgr manager.Manager, c client.Client) error {
@@ -161,7 +156,6 @@ func (r *reconcileIntegrationPlatform) Reconcile(ctx context.Context, request re
 		NewInitializeAction(),
 		NewCreateAction(),
 		NewMonitorAction(),
-		NewCreateCatalogAction(),
 	}
 
 	var targetPhase v1.IntegrationPlatformPhase
@@ -214,12 +208,5 @@ func (r *reconcileIntegrationPlatform) Reconcile(ctx context.Context, request re
 		break
 	}
 
-	if targetPhase == v1.IntegrationPlatformPhaseReady {
-		return reconcile.Result{}, nil
-	}
-
-	// Requeue
-	return reconcile.Result{
-		RequeueAfter: requeueAfterDuration,
-	}, nil
+	return reconcile.Result{}, nil
 }
