@@ -22,12 +22,11 @@ import (
 	"testing"
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
-	"github.com/apache/camel-k/v2/pkg/util/dsl"
 	"github.com/apache/camel-k/v2/pkg/util/test"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 	corev1 "k8s.io/api/core/v1"
-	"k8s.io/utils/pointer"
+	"k8s.io/utils/ptr"
 )
 
 func TestCreateIntegrationForPipe(t *testing.T) {
@@ -50,7 +49,7 @@ func TestCreateIntegrationForPipe(t *testing.T) {
 	assert.Equal(t, "camel.apache.org/v1", it.OwnerReferences[0].APIVersion)
 	assert.Equal(t, "Pipe", it.OwnerReferences[0].Kind)
 	assert.Equal(t, "my-pipe", it.OwnerReferences[0].Name)
-	dsl, err := dsl.ToYamlDSL(it.Spec.Flows)
+	dsl, err := v1.ToYamlDSL(it.Spec.Flows)
 	require.NoError(t, err)
 	assert.Equal(t, expectedNominalRoute(), string(dsl))
 }
@@ -75,7 +74,7 @@ func TestCreateIntegrationForPipeWithSinkErrorHandler(t *testing.T) {
 	assert.Equal(t, "#class:org.apache.camel.builder.DeadLetterChannelBuilder", it.Spec.GetConfigurationProperty("camel.beans.defaultErrorHandler"))
 	assert.Equal(t, "someUri", it.Spec.GetConfigurationProperty("camel.beans.defaultErrorHandler.deadLetterUri"))
 	assert.Equal(t, "defaultErrorHandler", it.Spec.GetConfigurationProperty(v1.ErrorHandlerRefName))
-	dsl, err := dsl.ToYamlDSL(it.Spec.Flows)
+	dsl, err := v1.ToYamlDSL(it.Spec.Flows)
 	require.NoError(t, err)
 	assert.Equal(t, expectedNominalRoute(), string(dsl))
 }
@@ -100,7 +99,7 @@ func TestCreateIntegrationForPipeWithLogErrorHandler(t *testing.T) {
 	assert.Equal(t, "#class:org.apache.camel.builder.DefaultErrorHandlerBuilder", it.Spec.GetConfigurationProperty("camel.beans.defaultErrorHandler"))
 	assert.Equal(t, "true", it.Spec.GetConfigurationProperty("camel.beans.defaultErrorHandler.showHeaders"))
 	assert.Equal(t, "defaultErrorHandler", it.Spec.GetConfigurationProperty(v1.ErrorHandlerRefName))
-	dsl, err := dsl.ToYamlDSL(it.Spec.Flows)
+	dsl, err := v1.ToYamlDSL(it.Spec.Flows)
 	require.NoError(t, err)
 	assert.Equal(t, expectedNominalRoute(), string(dsl))
 }
@@ -117,7 +116,7 @@ func TestCreateIntegrationForPipeDataType(t *testing.T) {
 	}
 	it, err := CreateIntegrationFor(context.TODO(), client, &pipe)
 	require.NoError(t, err)
-	dsl, err := dsl.ToYamlDSL(it.Spec.Flows)
+	dsl, err := v1.ToYamlDSL(it.Spec.Flows)
 	require.NoError(t, err)
 	assert.Equal(t, expectedNominalRouteWithDataType("data-type-action"), string(dsl))
 }
@@ -136,7 +135,7 @@ func TestCreateIntegrationForPipeDataTypeOverridden(t *testing.T) {
 	pipe.Annotations[v1.KameletDataTypeLabel] = newDataTypeKameletAction
 	it, err := CreateIntegrationFor(context.TODO(), client, &pipe)
 	require.NoError(t, err)
-	dsl, err := dsl.ToYamlDSL(it.Spec.Flows)
+	dsl, err := v1.ToYamlDSL(it.Spec.Flows)
 	require.NoError(t, err)
 	assert.Equal(t, expectedNominalRouteWithDataType(newDataTypeKameletAction), string(dsl))
 }
@@ -202,7 +201,7 @@ func TestExtractTraitAnnotations(t *testing.T) {
 	}
 	traits, err := extractAndDeleteTraits(client, annotations)
 	require.NoError(t, err)
-	assert.Equal(t, pointer.Bool(true), traits.Service.Enabled)
+	assert.Equal(t, ptr.To(true), traits.Service.Enabled)
 	assert.Equal(t, corev1.PullNever, traits.Container.ImagePullPolicy)
 	assert.Equal(t, "1.2.3", traits.Camel.RuntimeVersion)
 	assert.Equal(t, []string{"prop1=1", "prop2=2"}, traits.Camel.Properties)
@@ -256,5 +255,5 @@ func TestCreateIntegrationTraitsForPipeWithTraitAnnotations(t *testing.T) {
 	assert.Equal(t, map[string]string{
 		"my-annotation": "my-annotation-val",
 	}, it.Annotations)
-	assert.Equal(t, pointer.Bool(true), it.Spec.Traits.Service.Enabled)
+	assert.Equal(t, ptr.To(true), it.Spec.Traits.Service.Enabled)
 }
