@@ -93,9 +93,6 @@ func (t *builderTrait) Configure(e *Environment) (bool, *TraitCondition, error)
 	if e.IntegrationKit == nil {
 		return false, nil, nil
 	}
-	if e.CamelCatalog == nil {
-		return false, NewIntegrationConditionPlatformDisabledCatalogMissing(), nil
-	}
 	condition := t.adaptDeprecatedFields()
 	if e.Platform.Status.Build.PublishStrategy == v1.IntegrationPlatformBuildPublishStrategySpectrum {
 		condition = newOrAppend(condition, "Spectrum publishing strategy is deprecated and may be removed in future releases. Make sure to use any supported publishing strategy instead.")
@@ -191,7 +188,7 @@ func (t *builderTrait) adaptDeprecatedFields() *TraitCondition {
 		m := "The limit-memory parameter is deprecated and may be removed in future releases. Make sure to use tasks-limit-memory parameter instead."
 		t.L.Info(m)
 		if condition == nil {
-			condition = NewIntegrationCondition("Builder", v1.IntegrationConditionTraitInfo, corev1.ConditionTrue, traitConfigurationReason, "")
+			condition = NewIntegrationCondition("Builder", v1.IntegrationConditionTraitInfo, corev1.ConditionTrue, TraitConfigurationReason, "")
 		}
 		condition = newOrAppend(condition, m)
 		t.TasksLimitMemory = append(t.TasksLimitMemory, fmt.Sprintf("builder:%s", t.LimitMemory))
@@ -202,7 +199,7 @@ func (t *builderTrait) adaptDeprecatedFields() *TraitCondition {
 
 func newOrAppend(condition *TraitCondition, message string) *TraitCondition {
 	if condition == nil {
-		condition = NewIntegrationCondition("Builder", v1.IntegrationConditionTraitInfo, corev1.ConditionTrue, traitConfigurationReason, message)
+		condition = NewIntegrationCondition("Builder", v1.IntegrationConditionTraitInfo, corev1.ConditionTrue, TraitConfigurationReason, message)
 	} else {
 		condition.message += "; " + message
 	}
@@ -215,7 +212,11 @@ func (t *builderTrait) Apply(e *Environment) error {
 	var pipelineTasks []v1.Task
 
 	// task configuration resources
-	tasksConf, err := t.parseTasksConf()
+	defaultBuildConf := &v1.BuildConfiguration{}
+	if e.Platform != nil {
+		defaultBuildConf = &e.Platform.Status.Build.BuildConfiguration
+	}
+	tasksConf, err := t.parseTasksConf(defaultBuildConf)
 	if err != nil {
 		return err
 	}
@@ -542,7 +543,7 @@ func taskConfOrDefault(tasksConf map[string]*v1.BuildConfiguration, taskName str
 	return tasksConf[taskName]
 }
 
-func (t *builderTrait) parseTasksConf() (map[string]*v1.BuildConfiguration, error) {
+func (t *builderTrait) parseTasksConf(defaultBuildConf *v1.BuildConfiguration) (map[string]*v1.BuildConfiguration, error) {
 	tasksConf := make(map[string]*v1.BuildConfiguration)
 
 	for _, t := range t.TasksRequestCPU {
@@ -553,7 +554,7 @@ func (t *builderTrait) parseTasksConf() (map[string]*v1.BuildConfiguration, erro
 		taskName := splits[0]
 		taskResource := splits[1]
 		if tasksConf[taskName] == nil {
-			tasksConf[taskName] = &v1.BuildConfiguration{}
+			tasksConf[taskName] = defaultBuildConf
 		}
 		tasksConf[taskName].RequestCPU = taskResource
 	}
@@ -566,7 +567,7 @@ func (t *builderTrait) parseTasksConf() (map[string]*v1.BuildConfiguration, erro
 		taskName := splits[0]
 		taskResource := splits[1]
 		if tasksConf[taskName] == nil {
-			tasksConf[taskName] = &v1.BuildConfiguration{}
+			tasksConf[taskName] = defaultBuildConf
 		}
 		tasksConf[taskName].RequestMemory = taskResource
 	}
@@ -579,7 +580,7 @@ func (t *builderTrait) parseTasksConf() (map[string]*v1.BuildConfiguration, erro
 		taskName := splits[0]
 		taskResource := splits[1]
 		if tasksConf[taskName] == nil {
-			tasksConf[taskName] = &v1.BuildConfiguration{}
+			tasksConf[taskName] = defaultBuildConf
 		}
 		tasksConf[taskName].LimitCPU = taskResource
 	}
@@ -592,7 +593,7 @@ func (t *builderTrait) parseTasksConf() (map[string]*v1.BuildConfiguration, erro
 		taskName := splits[0]
 		taskResource := splits[1]
 		if tasksConf[taskName] == nil {
-			tasksConf[taskName] = &v1.BuildConfiguration{}
+			tasksConf[taskName] = defaultBuildConf
 		}
 		tasksConf[taskName].LimitMemory = taskResource
 	}
