@@ -42,6 +42,8 @@ const (
 type camelTrait struct {
 	BasePlatformTrait
 	traitv1.CamelTrait `property:",squash"`
+	// private configuration used only internally
+	runtimeVersion string
 }
 
 func newCamelTrait() Trait {
@@ -73,46 +75,67 @@ func (t *camelTrait) Configure(e *Environment) (bool, *TraitCondition, error) {
 		if runtimeVersion, err := determineRuntimeVersion(e); err != nil {
 			return false, nil, err
 		} else {
-			t.RuntimeVersion = runtimeVersion
+			t.runtimeVersion = runtimeVersion
+		}
+	} else {
+		t.runtimeVersion = t.RuntimeVersion
+	}
+
+	var cond *TraitCondition
+	//nolint: staticcheck
+	if (e.Integration != nil && !e.Integration.IsManagedBuild()) || (e.IntegrationKit != nil && e.IntegrationKit.IsSynthetic()) {
+		// We set a condition to warn the user the catalog used to run the Integration
+		// may differ from the runtime version which we don't control
+		cond = NewIntegrationCondition(
+			"Camel",
+			v1.IntegrationConditionTraitInfo,
+			corev1.ConditionTrue,
+			TraitConfigurationReason,
+			fmt.Sprintf(
+				"Operated with CamelCatalog version %s which may be different from the runtime used in the container",
+				t.runtimeVersion,
+			),
+		)
+	}
+
+	return true, cond, nil
+}
+
+func (t *camelTrait) Apply(e *Environment) error {
+	// This is an important action to do as most of the traits
+	// expects a CamelCatalog to be loaded regardless it's a managed or
+	// non managed build Integration
+	if e.CamelCatalog == nil {
+		if err := t.loadOrCreateCatalog(e, t.runtimeVersion); err != nil {
+			return err
 		}
 	}
 
-	return true, nil, nil
-}
-
-//nolint:nestif
-func (t *camelTrait) Apply(e *Environment) error {
-	if e.IntegrationKit != nil && e.IntegrationKit.IsSynthetic() {
-		// Synthetic Integration Kit
-
-		// This is required as during init phase, the trait set by default these values
-		// which are widely used in the platform for different purposese.
-		if e.Integration != nil {
-			e.Integration.Status.RuntimeVersion = ""
-			e.Integration.Status.RuntimeProvider = ""
-		}
-	} else {
-		// Managed Integration
-		if e.CamelCatalog == nil {
-			if err := t.loadOrCreateCatalog(e, t.RuntimeVersion); err != nil {
-				return err
-			}
-		}
-		e.RuntimeVersion = e.CamelCatalog.Runtime.Version
-		if e.Integration != nil {
+	if e.Integration != nil {
+		if e.Integration.IsManagedBuild() {
+			// If it's not managed we don't know which is the runtime running
 			e.Integration.Status.RuntimeVersion = e.CamelCatalog.Runtime.Version
 			e.Integration.Status.RuntimeProvider = e.CamelCatalog.Runtime.Provider
 		}
-		if e.IntegrationKit != nil {
+		e.Integration.Status.Catalog = &v1.Catalog{
+			Version:  e.CamelCatalog.Runtime.Version,
+			Provider: e.CamelCatalog.Runtime.Provider,
+		}
+	}
+	if e.IntegrationKit != nil {
+		//nolint: staticcheck
+		if !e.IntegrationKit.IsSynthetic() {
 			e.IntegrationKit.Status.RuntimeVersion = e.CamelCatalog.Runtime.Version
 			e.IntegrationKit.Status.RuntimeProvider = e.CamelCatalog.Runtime.Provider
 		}
+		e.IntegrationKit.Status.Catalog = &v1.Catalog{
+			Version:  e.CamelCatalog.Runtime.Version,
+			Provider: e.CamelCatalog.Runtime.Provider,
+		}
 	}
 
-	if e.IntegrationKitInPhase(v1.IntegrationKitPhaseReady) && e.IntegrationInRunningPhases() {
-		// Get all resources
-		maps := t.computeConfigMaps(e)
-		e.Resources.AddAll(maps)
+	if e.IntegrationInRunningPhases() {
+		e.Resources.AddAll(t.computeUserProperties(e))
 	}
 	return nil
 }
@@ -156,7 +179,23 @@ func (t *camelTrait) loadOrCreateCatalog(e *Environment, runtimeVersion string)
 	return nil
 }
 
-func (t *camelTrait) computeConfigMaps(e *Environment) []ctrl.Object {
+func determineRuntimeVersion(e *Environment) (string, error) {
+	if e.Integration != nil && e.Integration.Status.RuntimeVersion != "" {
+		return e.Integration.Status.RuntimeVersion, nil
+	}
+	if e.IntegrationKit != nil && e.IntegrationKit.Status.RuntimeVersion != "" {
+		return e.IntegrationKit.Status.RuntimeVersion, nil
+	}
+	if e.IntegrationProfile != nil && e.IntegrationProfile.Status.Build.RuntimeVersion != "" {
+		return e.IntegrationProfile.Status.Build.RuntimeVersion, nil
+	}
+	if e.Platform != nil && e.Platform.Status.Build.RuntimeVersion != "" {
+		return e.Platform.Status.Build.RuntimeVersion, nil
+	}
+	return "", errors.New("unable to determine runtime version")
+}
+
+func (t *camelTrait) computeUserProperties(e *Environment) []ctrl.Object {
 	sources := e.Integration.AllSources()
 	maps := make([]ctrl.Object, 0, len(sources)+1)
 
@@ -236,19 +275,3 @@ func (t *camelTrait) computeConfigMaps(e *Environment) []ctrl.Object {
 
 	return maps
 }
-
-func determineRuntimeVersion(e *Environment) (string, error) {
-	if e.Integration != nil && e.Integration.Status.RuntimeVersion != "" {
-		return e.Integration.Status.RuntimeVersion, nil
-	}
-	if e.IntegrationKit != nil && e.IntegrationKit.Status.RuntimeVersion != "" {
-		return e.IntegrationKit.Status.RuntimeVersion, nil
-	}
-	if e.IntegrationProfile != nil && e.IntegrationProfile.Status.Build.RuntimeVersion != "" {
-		return e.IntegrationProfile.Status.Build.RuntimeVersion, nil
-	}
-	if e.Platform != nil && e.Platform.Status.Build.RuntimeVersion != "" {
-		return e.Platform.Status.Build.RuntimeVersion, nil
-	}
-	return "", errors.New("unable to determine runtime version")
-}
