@@ -18,7 +18,6 @@ limitations under the License.
 package trait
 
 import (
-	"errors"
 	"fmt"
 	"path/filepath"
 
@@ -26,7 +25,7 @@ import (
 	batchv1 "k8s.io/api/batch/v1"
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/util/intstr"
-	"k8s.io/utils/pointer"
+	"k8s.io/utils/ptr"
 
 	serving "knative.dev/serving/pkg/apis/serving/v1"
 
@@ -34,10 +33,8 @@ import (
 	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
 	"github.com/apache/camel-k/v2/pkg/util"
 	"github.com/apache/camel-k/v2/pkg/util/camel"
-	"github.com/apache/camel-k/v2/pkg/util/defaults"
 	"github.com/apache/camel-k/v2/pkg/util/digest"
 	"github.com/apache/camel-k/v2/pkg/util/envvar"
-	"github.com/apache/camel-k/v2/pkg/util/knative"
 	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
 	"github.com/apache/camel-k/v2/pkg/util/openshift"
 )
@@ -69,20 +66,6 @@ type containerTrait struct {
 func newContainerTrait() Trait {
 	return &containerTrait{
 		BasePlatformTrait: NewBasePlatformTrait(containerTraitID, containerTraitOrder),
-		ContainerTrait: traitv1.ContainerTrait{
-			Port:                     defaultContainerPort,
-			ServicePort:              defaultServicePort,
-			ServicePortName:          defaultContainerPortName,
-			Name:                     defaultContainerName,
-			RunAsNonRoot:             pointer.Bool(defaultContainerRunAsNonRoot),
-			SeccompProfileType:       defaultContainerSeccompProfileType,
-			AllowPrivilegeEscalation: pointer.Bool(defaultContainerAllowPrivilegeEscalation),
-			CapabilitiesDrop:         []corev1.Capability{defaultContainerCapabilitiesDrop},
-			RequestCPU:               defaultContainerResourceCPU,
-			RequestMemory:            defaultContainerResourceMemory,
-			LimitCPU:                 defaultContainerLimitCPU,
-			LimitMemory:              defaultContainerLimitMemory,
-		},
 	}
 }
 
@@ -95,31 +78,11 @@ func (t *containerTrait) Configure(e *Environment) (bool, *TraitCondition, error
 		return false, nil, nil
 	}
 
-	knativeInstalled, _ := knative.IsEventingInstalled(e.Client)
-	if e.IntegrationInPhase(v1.IntegrationPhaseInitialization) && !knativeInstalled {
-		hasKnativeEndpoint, err := containsEndpoint("knative", e, t.Client)
-		if err != nil {
-			return false, nil, err
-		}
-
-		if hasKnativeEndpoint {
-			// fail fast the integration as there is no knative installed in the cluster
-			t.L.ForIntegration(e.Integration).Infof("Integration %s/%s contains knative endpoint that cannot run, as knative is not installed in the cluster.", e.Integration.Namespace, e.Integration.Name)
-			err := errors.New("integration cannot run, as knative is not installed in the cluster")
-			return false, NewIntegrationCondition(
-				"Container",
-				v1.IntegrationConditionKnativeAvailable,
-				corev1.ConditionFalse,
-				v1.IntegrationConditionKnativeNotInstalledReason,
-				err.Error(),
-			), err
-		}
-	}
-
-	if pointer.BoolDeref(t.Auto, true) {
+	if ptr.Deref(t.Auto, true) {
 		if t.Expose == nil {
-			e := e.Resources.GetServiceForIntegration(e.Integration) != nil
-			t.Expose = &e
+			if e.Resources.GetServiceForIntegration(e.Integration) != nil {
+				t.Expose = ptr.To(true)
+			}
 		}
 	}
 
@@ -152,43 +115,7 @@ func (t *containerTrait) configureImageIntegrationKit(e *Environment) error {
 			e.Integration.Spec.IntegrationKit)
 	}
 
-	kitName := fmt.Sprintf("kit-%s", e.Integration.Name)
-	kit := v1.NewIntegrationKit(e.Integration.Namespace, kitName)
-	kit.Spec.Image = t.Image
-
-	// Add some information for post-processing, this may need to be refactored
-	// to a proper data structure
-	kit.Labels = map[string]string{
-		v1.IntegrationKitTypeLabel:            v1.IntegrationKitTypeSynthetic,
-		kubernetes.CamelCreatorLabelKind:      v1.IntegrationKind,
-		kubernetes.CamelCreatorLabelName:      e.Integration.Name,
-		kubernetes.CamelCreatorLabelNamespace: e.Integration.Namespace,
-		kubernetes.CamelCreatorLabelVersion:   e.Integration.ResourceVersion,
-	}
-
-	if v, ok := e.Integration.Annotations[v1.PlatformSelectorAnnotation]; ok {
-		v1.SetAnnotation(&kit.ObjectMeta, v1.PlatformSelectorAnnotation, v)
-	}
-
-	if v, ok := e.Integration.Annotations[v1.IntegrationProfileAnnotation]; ok {
-		v1.SetAnnotation(&kit.ObjectMeta, v1.IntegrationProfileAnnotation, v)
-
-		if v, ok := e.Integration.Annotations[v1.IntegrationProfileNamespaceAnnotation]; ok {
-			v1.SetAnnotation(&kit.ObjectMeta, v1.IntegrationProfileNamespaceAnnotation, v)
-		} else {
-			// set integration profile namespace to the integration namespace.
-			// this is because the kit may live in another namespace and needs to resolve the integration profile from the integration namespace.
-			v1.SetAnnotation(&kit.ObjectMeta, v1.IntegrationProfileNamespaceAnnotation, e.Integration.Namespace)
-		}
-	}
-
-	operatorID := defaults.OperatorID()
-	if operatorID != "" {
-		kit.SetOperatorID(operatorID)
-	}
-
-	e.Resources.Add(kit)
-	e.Integration.SetIntegrationKit(kit)
+	e.Integration.Status.Image = t.Image
 
 	return nil
 }
@@ -198,7 +125,7 @@ func (t *containerTrait) configureContainer(e *Environment) error {
 		e.ApplicationProperties = make(map[string]string)
 	}
 	container := corev1.Container{
-		Name:  t.Name,
+		Name:  t.getContainerName(),
 		Image: e.Integration.Status.Image,
 		Env:   make([]corev1.EnvVar, 0),
 	}
@@ -261,14 +188,8 @@ func (t *containerTrait) configureContainer(e *Environment) error {
 	}); err != nil {
 		return err
 	}
-	e.addSourcesProperties()
-	if props, err := e.computeApplicationProperties(); err != nil {
-		return err
-	} else if props != nil {
-		e.Resources.Add(props)
-	}
 	t.configureResources(&container)
-	if knative || pointer.BoolDeref(t.Expose, false) {
+	if knative || ptr.Deref(t.Expose, false) {
 		t.configureService(e, &container, knative)
 	}
 	t.configureCapabilities(e)
@@ -290,7 +211,7 @@ func (t *containerTrait) configureService(e *Environment, container *corev1.Cont
 	}
 	containerPort := corev1.ContainerPort{
 		Name:          name,
-		ContainerPort: int32(t.Port),
+		ContainerPort: int32(t.getPort()),
 		Protocol:      corev1.ProtocolTCP,
 	}
 	if !isKnative {
@@ -298,8 +219,8 @@ func (t *containerTrait) configureService(e *Environment, container *corev1.Cont
 		service := e.Resources.GetServiceForIntegration(e.Integration)
 		if service != nil {
 			servicePort := corev1.ServicePort{
-				Name:       t.ServicePortName,
-				Port:       int32(t.ServicePort),
+				Name:       t.getServicePortName(),
+				Port:       int32(t.getServicePort()),
 				Protocol:   corev1.ProtocolTCP,
 				TargetPort: intstr.FromString(name),
 			}
@@ -331,21 +252,21 @@ func (t *containerTrait) configureResources(container *corev1.Container) {
 		limitsList = make(corev1.ResourceList)
 	}
 
-	requestsList, err = kubernetes.ConfigureResource(t.RequestCPU, requestsList, corev1.ResourceCPU)
+	requestsList, err = kubernetes.ConfigureResource(t.getRequestCPU(), requestsList, corev1.ResourceCPU)
 	if err != nil {
-		t.L.Error(err, "unable to parse quantity", "request-cpu", t.RequestCPU)
+		t.L.Error(err, "unable to parse quantity", "request-cpu", t.getRequestCPU())
 	}
-	requestsList, err = kubernetes.ConfigureResource(t.RequestMemory, requestsList, corev1.ResourceMemory)
+	requestsList, err = kubernetes.ConfigureResource(t.getRequestMemory(), requestsList, corev1.ResourceMemory)
 	if err != nil {
-		t.L.Error(err, "unable to parse quantity", "request-memory", t.RequestMemory)
+		t.L.Error(err, "unable to parse quantity", "request-memory", t.getRequestMemory())
 	}
-	limitsList, err = kubernetes.ConfigureResource(t.LimitCPU, limitsList, corev1.ResourceCPU)
+	limitsList, err = kubernetes.ConfigureResource(t.getLimitCPU(), limitsList, corev1.ResourceCPU)
 	if err != nil {
-		t.L.Error(err, "unable to parse quantity", "limit-cpu", t.LimitCPU)
+		t.L.Error(err, "unable to parse quantity", "limit-cpu", t.getLimitCPU())
 	}
-	limitsList, err = kubernetes.ConfigureResource(t.LimitMemory, limitsList, corev1.ResourceMemory)
+	limitsList, err = kubernetes.ConfigureResource(t.getLimitMemory(), limitsList, corev1.ResourceMemory)
 	if err != nil {
-		t.L.Error(err, "unable to parse quantity", "limit-memory", t.LimitMemory)
+		t.L.Error(err, "unable to parse quantity", "limit-memory", t.getLimitMemory())
 	}
 
 	container.Resources.Requests = requestsList
@@ -360,12 +281,12 @@ func (t *containerTrait) configureCapabilities(e *Environment) {
 
 func (t *containerTrait) setSecurityContext(e *Environment, container *corev1.Container) error {
 	sc := corev1.SecurityContext{
-		RunAsNonRoot: t.RunAsNonRoot,
+		RunAsNonRoot: t.getRunAsNonRoot(),
 		SeccompProfile: &corev1.SeccompProfile{
-			Type: t.SeccompProfileType,
+			Type: t.getSeccompProfileType(),
 		},
-		AllowPrivilegeEscalation: t.AllowPrivilegeEscalation,
-		Capabilities:             &corev1.Capabilities{Drop: t.CapabilitiesDrop, Add: t.CapabilitiesAdd},
+		AllowPrivilegeEscalation: t.getAllowPrivilegeEscalation(),
+		Capabilities:             &corev1.Capabilities{Drop: t.getCapabilitiesDrop(), Add: t.CapabilitiesAdd},
 	}
 
 	runAsUser, err := t.getUser(e)
@@ -402,3 +323,99 @@ func (t *containerTrait) getUser(e *Environment) (*int64, error) {
 
 	return runAsUser, nil
 }
+
+func (t *containerTrait) getPort() int {
+	if t.Port == 0 {
+		return defaultContainerPort
+	}
+
+	return t.Port
+}
+
+func (t *containerTrait) getServicePort() int {
+	if t.ServicePort == 0 {
+		return defaultServicePort
+	}
+
+	return t.ServicePort
+}
+
+func (t *containerTrait) getServicePortName() string {
+	if t.ServicePortName == "" {
+		return defaultContainerPortName
+	}
+
+	return t.ServicePortName
+}
+
+func (t *containerTrait) getContainerName() string {
+	if t.Name == "" {
+		return defaultContainerName
+	}
+
+	return t.Name
+}
+
+func (t *containerTrait) getRunAsNonRoot() *bool {
+	if t.RunAsNonRoot == nil {
+		return ptr.To(defaultContainerRunAsNonRoot)
+	}
+
+	return t.RunAsNonRoot
+}
+
+func (t *containerTrait) getSeccompProfileType() corev1.SeccompProfileType {
+	if t.SeccompProfileType == "" {
+		return defaultContainerSeccompProfileType
+	}
+
+	return t.SeccompProfileType
+}
+
+func (t *containerTrait) getAllowPrivilegeEscalation() *bool {
+	if t.AllowPrivilegeEscalation == nil {
+		return ptr.To(defaultContainerAllowPrivilegeEscalation)
+	}
+
+	return t.AllowPrivilegeEscalation
+}
+
+func (t *containerTrait) getCapabilitiesDrop() []corev1.Capability {
+	if t.CapabilitiesDrop == nil {
+		return []corev1.Capability{defaultContainerCapabilitiesDrop}
+	}
+
+	return t.CapabilitiesDrop
+}
+
+func (t *containerTrait) getRequestCPU() string {
+	if t.RequestCPU == "" {
+		return defaultContainerResourceCPU
+	}
+
+	return t.RequestCPU
+}
+
+func (t *containerTrait) getRequestMemory() string {
+	if t.RequestMemory == "" {
+		return defaultContainerResourceMemory
+	}
+
+	return t.RequestMemory
+}
+
+func (t *containerTrait) getLimitCPU() string {
+	if t.LimitCPU == "" {
+		return defaultContainerLimitCPU
+	}
+
+	return t.LimitCPU
+}
+
+func (t *containerTrait) getLimitMemory() string {
+	if t.LimitMemory == "" {
+		return defaultContainerLimitMemory
+	}
+
+	return t.LimitMemory
+}
