@@ -24,7 +24,7 @@ import (
 	"github.com/stretchr/testify/require"
 
 	corev1 "k8s.io/api/core/v1"
-	"k8s.io/utils/pointer"
+	"k8s.io/utils/ptr"
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
@@ -57,6 +57,7 @@ func newTestProbesEnv(t *testing.T, integration *v1.Integration) Environment {
 				},
 			},
 		},
+		IntegrationKit:        &v1.IntegrationKit{},
 		Integration:           integration,
 		Resources:             kubernetes.NewCollection(),
 		ApplicationProperties: make(map[string]string),
@@ -69,7 +70,7 @@ func TestProbesDependencies(t *testing.T) {
 			Traits: v1.Traits{
 				Health: &traitv1.HealthTrait{
 					Trait: traitv1.Trait{
-						Enabled: pointer.Bool(true),
+						Enabled: ptr.To(true),
 					},
 				},
 			},
@@ -79,8 +80,9 @@ func TestProbesDependencies(t *testing.T) {
 	env := newTestProbesEnv(t, integration)
 	env.Integration.Status.Phase = v1.IntegrationPhaseInitialization
 
-	conditions, err := env.Catalog.apply(&env)
+	conditions, traits, err := env.Catalog.apply(&env)
 	require.NoError(t, err)
+	assert.NotEmpty(t, traits)
 	assert.NotEmpty(t, conditions)
 	assert.Contains(t, env.Integration.Status.Dependencies, "mvn:org.apache.camel.quarkus:camel-quarkus-microprofile-health")
 }
@@ -91,10 +93,10 @@ func TestProbesOnDeployment(t *testing.T) {
 			Traits: v1.Traits{
 				Health: &traitv1.HealthTrait{
 					Trait: traitv1.Trait{
-						Enabled: pointer.Bool(true),
+						Enabled: ptr.To(true),
 					},
-					LivenessProbeEnabled:  pointer.Bool(true),
-					ReadinessProbeEnabled: pointer.Bool(true),
+					LivenessProbeEnabled:  ptr.To(true),
+					ReadinessProbeEnabled: ptr.To(true),
 					LivenessTimeout:       1234,
 				},
 			},
@@ -104,8 +106,9 @@ func TestProbesOnDeployment(t *testing.T) {
 	env := newTestProbesEnv(t, integration)
 	env.Integration.Status.Phase = v1.IntegrationPhaseDeploying
 
-	conditions, err := env.Catalog.apply(&env)
+	conditions, traits, err := env.Catalog.apply(&env)
 	require.NoError(t, err)
+	assert.NotEmpty(t, traits)
 	assert.NotEmpty(t, conditions)
 
 	container := env.GetIntegrationContainer()
@@ -127,10 +130,10 @@ func TestProbesOnDeploymentWithCustomScheme(t *testing.T) {
 			Traits: v1.Traits{
 				Health: &traitv1.HealthTrait{
 					Trait: traitv1.Trait{
-						Enabled: pointer.Bool(true),
+						Enabled: ptr.To(true),
 					},
-					LivenessProbeEnabled:  pointer.Bool(true),
-					ReadinessProbeEnabled: pointer.Bool(true),
+					LivenessProbeEnabled:  ptr.To(true),
+					ReadinessProbeEnabled: ptr.To(true),
 					LivenessScheme:        "HTTPS",
 					ReadinessScheme:       "HTTPS",
 					LivenessTimeout:       1234,
@@ -142,8 +145,9 @@ func TestProbesOnDeploymentWithCustomScheme(t *testing.T) {
 	env := newTestProbesEnv(t, integration)
 	env.Integration.Status.Phase = v1.IntegrationPhaseDeploying
 
-	conditions, err := env.Catalog.apply(&env)
+	conditions, traits, err := env.Catalog.apply(&env)
 	require.NoError(t, err)
+	assert.NotEmpty(t, traits)
 	assert.NotEmpty(t, conditions)
 
 	container := env.GetIntegrationContainer()
@@ -166,15 +170,15 @@ func TestProbesOnKnativeService(t *testing.T) {
 			Traits: v1.Traits{
 				KnativeService: &traitv1.KnativeServiceTrait{
 					Trait: traitv1.Trait{
-						Enabled: pointer.Bool(true),
+						Enabled: ptr.To(true),
 					},
 				},
 				Health: &traitv1.HealthTrait{
 					Trait: traitv1.Trait{
-						Enabled: pointer.Bool(true),
+						Enabled: ptr.To(true),
 					},
-					LivenessProbeEnabled:  pointer.Bool(true),
-					ReadinessProbeEnabled: pointer.Bool(true),
+					LivenessProbeEnabled:  ptr.To(true),
+					ReadinessProbeEnabled: ptr.To(true),
 					LivenessTimeout:       1234,
 				},
 			},
@@ -199,8 +203,9 @@ func TestProbesOnKnativeService(t *testing.T) {
 		"controller strategy: knative-service",
 	)
 
-	conditions, err := env.Catalog.apply(&env)
+	conditions, traits, err := env.Catalog.apply(&env)
 	require.NoError(t, err)
+	assert.NotEmpty(t, traits)
 	assert.Contains(t, conditions, ctrlStrategyCondition)
 	assert.Contains(t, conditions, serviceOverrideCondition)
 
