@@ -30,9 +30,7 @@ import (
 	"k8s.io/apimachinery/pkg/api/resource"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/types"
-	"k8s.io/utils/pointer"
-
-	ctrl "sigs.k8s.io/controller-runtime/pkg/client"
+	"k8s.io/utils/ptr"
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
@@ -88,9 +86,10 @@ func TestContainerWithDefaults(t *testing.T) {
 	}
 	environment.Platform.ResyncStatusFullConfig()
 
-	conditions, err := traitCatalog.apply(&environment)
+	conditions, traits, err := traitCatalog.apply(&environment)
 
 	require.NoError(t, err)
+	assert.Empty(t, traits)
 	assert.NotEmpty(t, conditions)
 	assert.NotEmpty(t, environment.ExecutedTraits)
 	assert.NotNil(t, environment.GetTrait("deployment"))
@@ -169,9 +168,10 @@ func TestContainerWithOpenshift(t *testing.T) {
 	}
 	environment.Platform.ResyncStatusFullConfig()
 
-	conditions, err := traitCatalog.apply(&environment)
+	conditions, traits, err := traitCatalog.apply(&environment)
 
 	require.NoError(t, err)
+	assert.NotEmpty(t, traits)
 	assert.NotEmpty(t, conditions)
 	assert.NotEmpty(t, environment.ExecutedTraits)
 	assert.NotNil(t, environment.GetTrait("deployment"))
@@ -182,8 +182,8 @@ func TestContainerWithOpenshift(t *testing.T) {
 	assert.NotNil(t, d)
 	assert.Len(t, d.Spec.Template.Spec.Containers, 1)
 	assert.Equal(t, defaultContainerName, d.Spec.Template.Spec.Containers[0].Name)
-	assert.Equal(t, pointer.Bool(defaultContainerRunAsNonRoot), d.Spec.Template.Spec.Containers[0].SecurityContext.RunAsNonRoot)
-	assert.Equal(t, pointer.Int64(1000860000), d.Spec.Template.Spec.Containers[0].SecurityContext.RunAsUser)
+	assert.Equal(t, ptr.To(defaultContainerRunAsNonRoot), d.Spec.Template.Spec.Containers[0].SecurityContext.RunAsNonRoot)
+	assert.Equal(t, ptr.To(int64(1000860000)), d.Spec.Template.Spec.Containers[0].SecurityContext.RunAsUser)
 }
 
 func TestContainerWithCustomName(t *testing.T) {
@@ -237,9 +237,10 @@ func TestContainerWithCustomName(t *testing.T) {
 	}
 	environment.Platform.ResyncStatusFullConfig()
 
-	conditions, err := traitCatalog.apply(&environment)
+	conditions, traits, err := traitCatalog.apply(&environment)
 
 	require.NoError(t, err)
+	assert.NotEmpty(t, traits)
 	assert.NotEmpty(t, conditions)
 	assert.NotEmpty(t, environment.ExecutedTraits)
 	assert.NotNil(t, environment.GetTrait("deployment"))
@@ -303,9 +304,10 @@ func TestContainerWithCustomImage(t *testing.T) {
 	}
 	environment.Platform.ResyncStatusFullConfig()
 
-	conditions, err := traitCatalog.apply(&environment)
+	conditions, traits, err := traitCatalog.apply(&environment)
 
 	require.NoError(t, err)
+	assert.NotEmpty(t, traits)
 	assert.NotEmpty(t, conditions)
 
 	for _, postAction := range environment.PostActions {
@@ -315,20 +317,8 @@ func TestContainerWithCustomImage(t *testing.T) {
 	assert.NotEmpty(t, environment.ExecutedTraits)
 	assert.NotNil(t, environment.GetTrait("deployer"))
 	assert.NotNil(t, environment.GetTrait("container"))
-	assert.Equal(t, "kit-"+ServiceTestName, environment.Integration.Status.IntegrationKit.Name)
-
-	ikt := v1.IntegrationKit{}
-	key := ctrl.ObjectKey{
-		Namespace: "ns",
-		Name:      "kit-" + ServiceTestName,
-	}
-
-	err = client.Get(context.TODO(), key, &ikt)
-	require.NoError(t, err)
-	assert.Equal(t, environment.Integration.ObjectMeta.UID, ikt.ObjectMeta.OwnerReferences[0].UID)
-
-	trait := environment.Integration.Spec.Traits.Container
-	assert.Equal(t, trait.Image, ikt.Spec.Image)
+	assert.Nil(t, environment.Integration.Status.IntegrationKit)
+	assert.Equal(t, environment.Integration.Spec.Traits.Container.Image, environment.Integration.Status.Image)
 }
 
 func TestContainerWithCustomImageAndIntegrationKit(t *testing.T) {
@@ -384,9 +374,10 @@ func TestContainerWithCustomImageAndIntegrationKit(t *testing.T) {
 	}
 	environment.Platform.ResyncStatusFullConfig()
 
-	conditions, err := traitCatalog.apply(&environment)
+	conditions, traits, err := traitCatalog.apply(&environment)
 	require.Error(t, err)
-	assert.Empty(t, conditions)
+	assert.Empty(t, traits)
+	assert.NotEmpty(t, conditions)
 	assert.Contains(t, err.Error(), "unsupported configuration: a container image has been set in conjunction with an IntegrationKit")
 }
 
@@ -398,10 +389,11 @@ func TestContainerWithImagePullPolicy(t *testing.T) {
 	traitCatalog := NewCatalog(nil)
 
 	environment := Environment{
-		Ctx:          context.TODO(),
-		Client:       client,
-		CamelCatalog: catalog,
-		Catalog:      traitCatalog,
+		Ctx:            context.TODO(),
+		Client:         client,
+		CamelCatalog:   catalog,
+		Catalog:        traitCatalog,
+		IntegrationKit: &v1.IntegrationKit{},
 		Integration: &v1.Integration{
 			Spec: v1.IntegrationSpec{
 				Profile: v1.TraitProfileKubernetes,
@@ -427,9 +419,10 @@ func TestContainerWithImagePullPolicy(t *testing.T) {
 	environment.Integration.Status.Phase = v1.IntegrationPhaseDeploying
 	environment.Platform.ResyncStatusFullConfig()
 
-	conditions, err := traitCatalog.apply(&environment)
+	conditions, traits, err := traitCatalog.apply(&environment)
 
 	require.NoError(t, err)
+	assert.NotEmpty(t, traits)
 	assert.NotEmpty(t, conditions)
 
 	container := environment.GetIntegrationContainer()
@@ -437,98 +430,6 @@ func TestContainerWithImagePullPolicy(t *testing.T) {
 	assert.Equal(t, corev1.PullAlways, container.ImagePullPolicy)
 }
 
-func TestRunKnativeEndpointWithKnativeNotInstalled(t *testing.T) {
-	environment := createEnvironment()
-	trait, _ := newContainerTrait().(*containerTrait)
-	environment.Integration.Spec.Sources = []v1.SourceSpec{
-		{
-			DataSpec: v1.DataSpec{
-				Name: "test.java",
-				Content: `
-				from("knative:channel/test").to("log:${body};
-			`,
-			},
-			Language: v1.LanguageJavaSource,
-		},
-	}
-	expectedCondition := NewIntegrationCondition(
-		"Container",
-		v1.IntegrationConditionKnativeAvailable,
-		corev1.ConditionFalse,
-		v1.IntegrationConditionKnativeNotInstalledReason,
-		"integration cannot run, as knative is not installed in the cluster",
-	)
-	configured, condition, err := trait.Configure(environment)
-	require.Error(t, err)
-	assert.Equal(t, expectedCondition, condition)
-	assert.False(t, configured)
-}
-
-func TestRunNonKnativeEndpointWithKnativeNotInstalled(t *testing.T) {
-	environment := createEnvironment()
-	trait, _ := newContainerTrait().(*containerTrait)
-	environment.Integration.Spec.Sources = []v1.SourceSpec{
-		{
-			DataSpec: v1.DataSpec{
-				Name: "test.java",
-				Content: `
-				from("platform-http://my-site").to("log:${body}");
-			`,
-			},
-			Language: v1.LanguageJavaSource,
-		},
-	}
-
-	configured, condition, err := trait.Configure(environment)
-	require.NoError(t, err)
-	assert.Nil(t, condition)
-	assert.True(t, configured)
-	conditions := environment.Integration.Status.Conditions
-	assert.Empty(t, conditions)
-}
-
-func createEnvironment() *Environment {
-	client, _ := test.NewFakeClient()
-	// disable the knative eventing api
-	fakeClient := client.(*test.FakeClient) //nolint
-	fakeClient.DisableAPIGroupDiscovery("eventing.knative.dev/v1")
-
-	replicas := int32(3)
-	catalog, _ := camel.QuarkusCatalog()
-
-	environment := &Environment{
-		CamelCatalog: catalog,
-		Catalog:      NewCatalog(nil),
-		Client:       client,
-		Integration: &v1.Integration{
-			ObjectMeta: metav1.ObjectMeta{
-				Name: "integration-name",
-			},
-			Spec: v1.IntegrationSpec{
-				Replicas: &replicas,
-				Traits:   v1.Traits{},
-			},
-			Status: v1.IntegrationStatus{
-				Phase: v1.IntegrationPhaseInitialization,
-			},
-		},
-		Platform: &v1.IntegrationPlatform{
-			ObjectMeta: metav1.ObjectMeta{
-				Namespace: "namespace",
-			},
-			Spec: v1.IntegrationPlatformSpec{
-				Cluster: v1.IntegrationPlatformClusterKubernetes,
-				Profile: v1.TraitProfileKubernetes,
-			},
-		},
-		Resources:             kubernetes.NewCollection(),
-		ApplicationProperties: make(map[string]string),
-	}
-	environment.Platform.ResyncStatusFullConfig()
-
-	return environment
-}
-
 func TestDeploymentContainerPorts(t *testing.T) {
 	catalog, err := camel.DefaultCatalog()
 	require.NoError(t, err)
@@ -537,10 +438,11 @@ func TestDeploymentContainerPorts(t *testing.T) {
 	traitCatalog := NewCatalog(nil)
 
 	environment := Environment{
-		Ctx:          context.TODO(),
-		Client:       client,
-		CamelCatalog: catalog,
-		Catalog:      traitCatalog,
+		Ctx:            context.TODO(),
+		Client:         client,
+		CamelCatalog:   catalog,
+		Catalog:        traitCatalog,
+		IntegrationKit: &v1.IntegrationKit{},
 		Integration: &v1.Integration{
 			Spec: v1.IntegrationSpec{
 				Profile: v1.TraitProfileKubernetes,
@@ -583,7 +485,7 @@ func TestDeploymentContainerPorts(t *testing.T) {
 	environment.Integration.Status.Phase = v1.IntegrationPhaseDeploying
 	environment.Platform.ResyncStatusFullConfig()
 
-	_, err = traitCatalog.apply(&environment)
+	_, _, err = traitCatalog.apply(&environment)
 	require.NoError(t, err)
 	container := environment.GetIntegrationContainer()
 	assert.Len(t, container.Ports, 1)
@@ -602,10 +504,11 @@ func TestKnativeServiceContainerPorts(t *testing.T) {
 	traitCatalog := NewCatalog(nil)
 
 	environment := Environment{
-		Ctx:          context.TODO(),
-		Client:       client,
-		CamelCatalog: catalog,
-		Catalog:      traitCatalog,
+		Ctx:            context.TODO(),
+		Client:         client,
+		CamelCatalog:   catalog,
+		Catalog:        traitCatalog,
+		IntegrationKit: &v1.IntegrationKit{},
 		Integration: &v1.Integration{
 			Spec: v1.IntegrationSpec{
 				Profile: v1.TraitProfileKnative,
@@ -648,7 +551,7 @@ func TestKnativeServiceContainerPorts(t *testing.T) {
 	environment.Integration.Status.Phase = v1.IntegrationPhaseDeploying
 	environment.Platform.ResyncStatusFullConfig()
 
-	_, err = traitCatalog.apply(&environment)
+	_, _, err = traitCatalog.apply(&environment)
 	require.NoError(t, err)
 	container := environment.GetIntegrationContainer()
 	assert.Len(t, container.Ports, 1)
@@ -660,9 +563,10 @@ func TestDefaultKubernetesSecurityContext(t *testing.T) {
 	environment := createSettingContextEnvironment(t, v1.TraitProfileKubernetes)
 	traitCatalog := NewCatalog(nil)
 
-	conditions, err := traitCatalog.apply(environment)
+	conditions, traits, err := traitCatalog.apply(environment)
 
 	require.NoError(t, err)
+	assert.Empty(t, traits)
 	assert.NotEmpty(t, conditions)
 	assert.NotEmpty(t, environment.ExecutedTraits)
 	assert.NotNil(t, environment.GetTrait("deployment"))
@@ -673,21 +577,27 @@ func TestDefaultKubernetesSecurityContext(t *testing.T) {
 	assert.NotNil(t, d)
 	assert.Len(t, d.Spec.Template.Spec.Containers, 1)
 	assert.Equal(t, defaultContainerName, d.Spec.Template.Spec.Containers[0].Name)
-	assert.Equal(t, pointer.Bool(defaultContainerRunAsNonRoot), d.Spec.Template.Spec.Containers[0].SecurityContext.RunAsNonRoot)
+	assert.Equal(t, ptr.To(defaultContainerRunAsNonRoot), d.Spec.Template.Spec.Containers[0].SecurityContext.RunAsNonRoot)
 	assert.Nil(t, d.Spec.Template.Spec.Containers[0].SecurityContext.RunAsUser)
 	assert.Equal(t, corev1.SeccompProfileTypeRuntimeDefault, d.Spec.Template.Spec.Containers[0].SecurityContext.SeccompProfile.Type)
-	assert.Equal(t, pointer.Bool(defaultContainerAllowPrivilegeEscalation), d.Spec.Template.Spec.Containers[0].SecurityContext.AllowPrivilegeEscalation)
+	assert.Equal(t, ptr.To(defaultContainerAllowPrivilegeEscalation), d.Spec.Template.Spec.Containers[0].SecurityContext.AllowPrivilegeEscalation)
 	assert.Equal(t, []corev1.Capability{defaultContainerCapabilitiesDrop}, d.Spec.Template.Spec.Containers[0].SecurityContext.Capabilities.Drop)
 	assert.Nil(t, d.Spec.Template.Spec.Containers[0].SecurityContext.Capabilities.Add)
 }
 
 func TestDefaultKnativeSecurityContext(t *testing.T) {
 	environment := createSettingContextEnvironment(t, v1.TraitProfileKnative)
+	environment.Integration.Spec.Traits.KnativeService = &traitv1.KnativeServiceTrait{
+		Trait: traitv1.Trait{
+			Enabled: ptr.To(true),
+		},
+	}
 	traitCatalog := NewCatalog(nil)
 
-	conditions, err := traitCatalog.apply(environment)
+	conditions, traits, err := traitCatalog.apply(environment)
 
 	require.NoError(t, err)
+	assert.NotEmpty(t, traits)
 	assert.NotEmpty(t, conditions)
 	assert.NotEmpty(t, environment.ExecutedTraits)
 	assert.Nil(t, environment.GetTrait("deployment"))
@@ -701,10 +611,10 @@ func TestDefaultKnativeSecurityContext(t *testing.T) {
 	assert.NotNil(t, s)
 	assert.Len(t, s.Spec.Template.Spec.Containers, 1)
 	assert.Equal(t, defaultContainerName, s.Spec.Template.Spec.Containers[0].Name)
-	assert.Equal(t, pointer.Bool(defaultContainerRunAsNonRoot), s.Spec.Template.Spec.Containers[0].SecurityContext.RunAsNonRoot)
+	assert.Equal(t, ptr.To(defaultContainerRunAsNonRoot), s.Spec.Template.Spec.Containers[0].SecurityContext.RunAsNonRoot)
 	assert.Nil(t, s.Spec.Template.Spec.Containers[0].SecurityContext.RunAsUser)
 	assert.Equal(t, corev1.SeccompProfileTypeRuntimeDefault, s.Spec.Template.Spec.Containers[0].SecurityContext.SeccompProfile.Type)
-	assert.Equal(t, pointer.Bool(defaultContainerAllowPrivilegeEscalation), s.Spec.Template.Spec.Containers[0].SecurityContext.AllowPrivilegeEscalation)
+	assert.Equal(t, ptr.To(defaultContainerAllowPrivilegeEscalation), s.Spec.Template.Spec.Containers[0].SecurityContext.AllowPrivilegeEscalation)
 	assert.Equal(t, []corev1.Capability{defaultContainerCapabilitiesDrop}, s.Spec.Template.Spec.Containers[0].SecurityContext.Capabilities.Drop)
 	assert.Nil(t, s.Spec.Template.Spec.Containers[0].SecurityContext.Capabilities.Add)
 }
@@ -713,19 +623,20 @@ func TestUserSecurityContext(t *testing.T) {
 	environment := createSettingContextEnvironment(t, v1.TraitProfileKubernetes)
 	environment.Integration.Spec.Traits = v1.Traits{
 		Container: &traitv1.ContainerTrait{
-			RunAsNonRoot:             pointer.Bool(false),
-			RunAsUser:                pointer.Int64(1000),
+			RunAsNonRoot:             ptr.To(false),
+			RunAsUser:                ptr.To(int64(1000)),
 			SeccompProfileType:       "Unconfined",
-			AllowPrivilegeEscalation: pointer.Bool(true),
+			AllowPrivilegeEscalation: ptr.To(true),
 			CapabilitiesDrop:         []corev1.Capability{"DROP"},
 			CapabilitiesAdd:          []corev1.Capability{"ADD"},
 		},
 	}
 	traitCatalog := NewCatalog(nil)
 
-	conditions, err := traitCatalog.apply(environment)
+	conditions, traits, err := traitCatalog.apply(environment)
 
 	require.NoError(t, err)
+	assert.NotEmpty(t, traits)
 	assert.NotEmpty(t, conditions)
 	assert.NotEmpty(t, environment.ExecutedTraits)
 	assert.NotNil(t, environment.GetTrait("deployment"))
@@ -735,10 +646,10 @@ func TestUserSecurityContext(t *testing.T) {
 
 	assert.NotNil(t, d)
 	assert.Len(t, d.Spec.Template.Spec.Containers, 1)
-	assert.Equal(t, pointer.Bool(false), d.Spec.Template.Spec.Containers[0].SecurityContext.RunAsNonRoot)
-	assert.Equal(t, pointer.Int64(1000), d.Spec.Template.Spec.Containers[0].SecurityContext.RunAsUser)
+	assert.Equal(t, ptr.To(false), d.Spec.Template.Spec.Containers[0].SecurityContext.RunAsNonRoot)
+	assert.Equal(t, ptr.To(int64(1000)), d.Spec.Template.Spec.Containers[0].SecurityContext.RunAsUser)
 	assert.Equal(t, corev1.SeccompProfileTypeUnconfined, d.Spec.Template.Spec.Containers[0].SecurityContext.SeccompProfile.Type)
-	assert.Equal(t, pointer.Bool(true), d.Spec.Template.Spec.Containers[0].SecurityContext.AllowPrivilegeEscalation)
+	assert.Equal(t, ptr.To(true), d.Spec.Template.Spec.Containers[0].SecurityContext.AllowPrivilegeEscalation)
 	assert.Equal(t, []corev1.Capability{"DROP"}, d.Spec.Template.Spec.Containers[0].SecurityContext.Capabilities.Drop)
 	assert.Equal(t, []corev1.Capability{"ADD"}, d.Spec.Template.Spec.Containers[0].SecurityContext.Capabilities.Add)
 }
@@ -746,9 +657,10 @@ func TestUserSecurityContext(t *testing.T) {
 func TestUserDefaultResources(t *testing.T) {
 	environment := createSettingContextEnvironment(t, v1.TraitProfileKubernetes)
 	traitCatalog := NewCatalog(nil)
-	conditions, err := traitCatalog.apply(environment)
+	conditions, traits, err := traitCatalog.apply(environment)
 
 	require.NoError(t, err)
+	assert.Empty(t, traits)
 	assert.NotEmpty(t, conditions)
 	assert.NotEmpty(t, environment.ExecutedTraits)
 	assert.NotNil(t, environment.GetTrait("deployment"))
