@@ -30,6 +30,14 @@ import (
 	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
 )
 
+const (
+	deploymentTraitID               = "deployment"
+	deploymentTraitOrder            = 1100
+	deploymentStrategySelectorOrder = 10000
+
+	defaultProgressDeadline = int32(60)
+)
+
 type deploymentTrait struct {
 	BasePlatformTrait
 	traitv1.DeploymentTrait `property:",squash"`
@@ -39,7 +47,7 @@ var _ ControllerStrategySelector = &deploymentTrait{}
 
 func newDeploymentTrait() Trait {
 	return &deploymentTrait{
-		BasePlatformTrait: NewBasePlatformTrait("deployment", 1100),
+		BasePlatformTrait: NewBasePlatformTrait(deploymentTraitID, deploymentTraitOrder),
 	}
 }
 
@@ -84,7 +92,7 @@ func (t *deploymentTrait) SelectControllerStrategy(e *Environment) (*ControllerS
 }
 
 func (t *deploymentTrait) ControllerStrategySelectorOrder() int {
-	return 10000
+	return deploymentStrategySelectorOrder
 }
 
 func (t *deploymentTrait) Apply(e *Environment) error {
@@ -110,7 +118,7 @@ func (t *deploymentTrait) getDeploymentFor(e *Environment) *appsv1.Deployment {
 		}
 	}
 
-	deadline := int32(60)
+	deadline := defaultProgressDeadline
 	if t.ProgressDeadlineSeconds != nil {
 		deadline = *t.ProgressDeadlineSeconds
 	}
