@@ -18,6 +18,7 @@ limitations under the License.
 package trait
 
 import (
+	"fmt"
 	"testing"
 
 	"github.com/stretchr/testify/assert"
@@ -26,7 +27,7 @@ import (
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
-	"k8s.io/utils/pointer"
+	"k8s.io/utils/ptr"
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
@@ -42,8 +43,9 @@ func TestDefaultEnvironment(t *testing.T) {
 	env := mockEnvironment(catalog)
 	env.Platform.ResyncStatusFullConfig()
 
-	conditions, err := NewEnvironmentTestCatalog().apply(&env)
+	conditions, traits, err := NewEnvironmentTestCatalog().apply(&env)
 	require.NoError(t, err)
+	assert.Empty(t, traits)
 	assert.NotEmpty(t, conditions)
 
 	ns := false
@@ -86,13 +88,14 @@ func TestEnabledContainerMetaDataEnvVars(t *testing.T) {
 	env := mockEnvironment(c)
 	env.Integration.Spec.Traits = v1.Traits{
 		Environment: &traitv1.EnvironmentTrait{
-			ContainerMeta: pointer.Bool(true),
+			ContainerMeta: ptr.To(true),
 		},
 	}
 	env.Platform.ResyncStatusFullConfig()
 
-	conditions, err := NewEnvironmentTestCatalog().apply(&env)
+	conditions, traits, err := NewEnvironmentTestCatalog().apply(&env)
 	require.NoError(t, err)
+	assert.NotEmpty(t, traits)
 	assert.NotEmpty(t, conditions)
 
 	ns := false
@@ -125,14 +128,15 @@ func TestDisabledContainerMetaDataEnvVars(t *testing.T) {
 	env := mockEnvironment(c)
 	env.Integration.Spec.Traits = v1.Traits{
 		Environment: &traitv1.EnvironmentTrait{
-			ContainerMeta: pointer.Bool(false),
+			ContainerMeta: ptr.To(false),
 		},
 	}
 
 	env.Platform.ResyncStatusFullConfig()
 
-	conditions, err := NewEnvironmentTestCatalog().apply(&env)
+	conditions, traits, err := NewEnvironmentTestCatalog().apply(&env)
 	require.NoError(t, err)
+	assert.NotEmpty(t, traits)
 	assert.NotEmpty(t, conditions)
 
 	ns := false
@@ -170,8 +174,9 @@ func TestCustomEnvVars(t *testing.T) {
 	}
 	env.Platform.ResyncStatusFullConfig()
 
-	conditions, err := NewEnvironmentTestCatalog().apply(&env)
+	conditions, traits, err := NewEnvironmentTestCatalog().apply(&env)
 	require.NoError(t, err)
+	assert.NotEmpty(t, traits)
 	assert.NotEmpty(t, conditions)
 
 	userK1 := false
@@ -192,6 +197,46 @@ func TestCustomEnvVars(t *testing.T) {
 	assert.True(t, userK2)
 }
 
+func TestValueSourceEnvVars(t *testing.T) {
+	c, err := camel.DefaultCatalog()
+	require.NoError(t, err)
+
+	env := mockEnvironment(c)
+	env.Integration.Spec.Traits = v1.Traits{
+		Environment: &traitv1.EnvironmentTrait{
+			Vars: []string{"MY_VAR_1=secret:my-sec/my-sec-value", "MY_VAR_2=configmap:my-cm/my-cm-value"},
+		},
+	}
+	env.Platform.ResyncStatusFullConfig()
+
+	conditions, traits, err := NewEnvironmentTestCatalog().apply(&env)
+	require.NoError(t, err)
+	assert.NotEmpty(t, traits)
+	assert.NotEmpty(t, conditions)
+
+	userK1 := false
+	userK2 := false
+
+	env.Resources.VisitDeployment(func(deployment *appsv1.Deployment) {
+		fmt.Println(deployment.Spec.Template.Spec.Containers[0].Env)
+		for _, e := range deployment.Spec.Template.Spec.Containers[0].Env {
+			if e.Name == "MY_VAR_1" {
+				userK1 = e.Value == "" &&
+					e.ValueFrom.SecretKeyRef.Name == "my-sec" &&
+					e.ValueFrom.SecretKeyRef.Key == "my-sec-value"
+			}
+			if e.Name == "MY_VAR_2" {
+				userK2 = e.Value == "" &&
+					e.ValueFrom.ConfigMapKeyRef.Name == "my-cm" &&
+					e.ValueFrom.ConfigMapKeyRef.Key == "my-cm-value"
+			}
+		}
+	})
+
+	assert.True(t, userK1)
+	assert.True(t, userK2)
+}
+
 func NewEnvironmentTestCatalog() *Catalog {
 	return NewCatalog(nil)
 }
