@@ -25,7 +25,7 @@ import (
 
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
-	"k8s.io/utils/pointer"
+	"k8s.io/utils/ptr"
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	"github.com/apache/camel-k/v2/pkg/util/boolean"
@@ -53,10 +53,11 @@ func TestApplyJolokiaTraitNominalShouldSucceed(t *testing.T) {
 	container := environment.Resources.GetContainerByName(defaultContainerName)
 	assert.NotNil(t, container)
 
-	assert.Equal(t, container.Args, []string{
+	assert.Equal(t, []string{
 		"-javaagent:dependencies/lib/main/org.jolokia.jolokia-agent-jvm-1.7.1.jar=discoveryEnabled=false,host=*,port=8778",
 		"-cp", "dependencies/lib/main/org.jolokia.jolokia-agent-jvm-1.7.1.jar",
-	})
+	},
+		container.Args)
 
 	assert.Len(t, container.Ports, 1)
 	containerPort := container.Ports[0]
@@ -214,7 +215,7 @@ func TestSetDefaultBoolJolokiaOptionShouldSucceed(t *testing.T) {
 func TestSetDefaultBoolJolokiaOptionShouldNotOverrideExistingValue(t *testing.T) {
 	trait, _ := newJolokiaTrait().(*jolokiaTrait)
 	options := map[string]string{}
-	option := pointer.Bool(false)
+	option := ptr.To(false)
 
 	trait.setDefaultJolokiaOption(options, &option, "key", true)
 
@@ -257,7 +258,7 @@ func TestAddBoolPointerOptionToJolokiaOptions(t *testing.T) {
 	trait, _ := newJolokiaTrait().(*jolokiaTrait)
 	options := map[string]string{}
 
-	trait.addToJolokiaOptions(options, "key", pointer.Bool(false))
+	trait.addToJolokiaOptions(options, "key", ptr.To(false))
 
 	assert.Len(t, options, 1)
 	assert.Equal(t, boolean.FalseString, options["key"])
@@ -274,7 +275,7 @@ func TestAddWrongTypeOptionToJolokiaOptionsDoesNothing(t *testing.T) {
 
 func createNominalJolokiaTest() (*jolokiaTrait, *Environment) {
 	trait, _ := newJolokiaTrait().(*jolokiaTrait)
-	trait.Enabled = pointer.Bool(true)
+	trait.Enabled = ptr.To(true)
 
 	environment := &Environment{
 		Catalog: NewCatalog(nil),
