@@ -28,7 +28,7 @@ import (
 
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
-	"k8s.io/utils/pointer"
+	"k8s.io/utils/ptr"
 
 	eventingduckv1 "knative.dev/eventing/pkg/apis/duck/v1"
 	eventing "knative.dev/eventing/pkg/apis/eventing/v1"
@@ -44,11 +44,14 @@ import (
 	"github.com/apache/camel-k/v2/pkg/util/boolean"
 	"github.com/apache/camel-k/v2/pkg/util/camel"
 	"github.com/apache/camel-k/v2/pkg/util/knative"
+	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
 	k8sutils "github.com/apache/camel-k/v2/pkg/util/kubernetes"
 	"github.com/apache/camel-k/v2/pkg/util/test"
 )
 
 func TestKnativeEnvConfigurationFromTrait(t *testing.T) {
+	client, err := test.NewFakeClient()
+	require.NoError(t, err)
 	catalog, err := camel.DefaultCatalog()
 	require.NoError(t, err)
 
@@ -57,6 +60,7 @@ func TestKnativeEnvConfigurationFromTrait(t *testing.T) {
 	environment := Environment{
 		CamelCatalog: catalog,
 		Catalog:      traitCatalog,
+		Client:       client,
 		Integration: &v1.Integration{
 			ObjectMeta: metav1.ObjectMeta{
 				Name:      "test",
@@ -71,9 +75,9 @@ func TestKnativeEnvConfigurationFromTrait(t *testing.T) {
 				Traits: v1.Traits{
 					Knative: &traitv1.KnativeTrait{
 						Trait: traitv1.Trait{
-							Enabled: pointer.Bool(true),
+							Enabled: ptr.To(true),
 						},
-						Auto:            pointer.Bool(false),
+						Auto:            ptr.To(false),
 						ChannelSources:  []string{"channel-source-1"},
 						ChannelSinks:    []string{"channel-sink-1"},
 						EndpointSources: []string{"endpoint-source-1"},
@@ -160,6 +164,8 @@ func TestKnativeEnvConfigurationFromTrait(t *testing.T) {
 }
 
 func TestKnativeEnvConfigurationFromSource(t *testing.T) {
+	client, err := test.NewFakeClient()
+	require.NoError(t, err)
 	catalog, err := camel.DefaultCatalog()
 	require.NoError(t, err)
 
@@ -168,6 +174,7 @@ func TestKnativeEnvConfigurationFromSource(t *testing.T) {
 	environment := Environment{
 		CamelCatalog: catalog,
 		Catalog:      traitCatalog,
+		Client:       client,
 		Integration: &v1.Integration{
 			ObjectMeta: metav1.ObjectMeta{
 				Name:      "test",
@@ -203,7 +210,7 @@ func TestKnativeEnvConfigurationFromSource(t *testing.T) {
 				Traits: v1.Traits{
 					Knative: &traitv1.KnativeTrait{
 						Trait: traitv1.Trait{
-							Enabled: pointer.Bool(true),
+							Enabled: ptr.To(true),
 						},
 					},
 				},
@@ -315,7 +322,7 @@ func TestKnativeTriggerExplicitFilterConfig(t *testing.T) {
 				Traits: v1.Traits{
 					Knative: &traitv1.KnativeTrait{
 						Trait: traitv1.Trait{
-							Enabled: pointer.Bool(true),
+							Enabled: ptr.To(true),
 						},
 						Filters: []string{"source=my-source"},
 					},
@@ -348,7 +355,7 @@ func TestKnativeTriggerExplicitFilterConfig(t *testing.T) {
 	environment.Platform.ResyncStatusFullConfig()
 
 	// don't care about conditions in this unit test
-	_, err = traitCatalog.apply(&environment)
+	_, _, err = traitCatalog.apply(&environment)
 
 	require.NoError(t, err)
 	assert.NotEmpty(t, environment.ExecutedTraits)
@@ -414,10 +421,10 @@ func TestKnativeTriggerExplicitFilterConfigNoEventTypeFilter(t *testing.T) {
 				Traits: v1.Traits{
 					Knative: &traitv1.KnativeTrait{
 						Trait: traitv1.Trait{
-							Enabled: pointer.Bool(true),
+							Enabled: ptr.To(true),
 						},
 						Filters:         []string{"source=my-source"},
-						FilterEventType: pointer.Bool(false),
+						FilterEventType: ptr.To(false),
 					},
 				},
 			},
@@ -448,7 +455,7 @@ func TestKnativeTriggerExplicitFilterConfigNoEventTypeFilter(t *testing.T) {
 	environment.Platform.ResyncStatusFullConfig()
 
 	// don't care about conditions in this unit test
-	_, err = traitCatalog.apply(&environment)
+	_, _, err = traitCatalog.apply(&environment)
 
 	require.NoError(t, err)
 	assert.NotEmpty(t, environment.ExecutedTraits)
@@ -513,7 +520,7 @@ func TestKnativeTriggerDefaultEventTypeFilter(t *testing.T) {
 				Traits: v1.Traits{
 					Knative: &traitv1.KnativeTrait{
 						Trait: traitv1.Trait{
-							Enabled: pointer.Bool(true),
+							Enabled: ptr.To(true),
 						},
 					},
 				},
@@ -545,7 +552,7 @@ func TestKnativeTriggerDefaultEventTypeFilter(t *testing.T) {
 	environment.Platform.ResyncStatusFullConfig()
 
 	// don't care about conditions in this unit test
-	_, err = traitCatalog.apply(&environment)
+	_, _, err = traitCatalog.apply(&environment)
 
 	require.NoError(t, err)
 	assert.NotEmpty(t, environment.ExecutedTraits)
@@ -609,9 +616,9 @@ func TestKnativeTriggerDefaultEventTypeFilterDisabled(t *testing.T) {
 				Traits: v1.Traits{
 					Knative: &traitv1.KnativeTrait{
 						Trait: traitv1.Trait{
-							Enabled: pointer.Bool(true),
+							Enabled: ptr.To(true),
 						},
-						FilterEventType: pointer.Bool(false),
+						FilterEventType: ptr.To(false),
 					},
 				},
 			},
@@ -642,7 +649,7 @@ func TestKnativeTriggerDefaultEventTypeFilterDisabled(t *testing.T) {
 	environment.Platform.ResyncStatusFullConfig()
 
 	// don't care about conditions in this unit test
-	_, err = traitCatalog.apply(&environment)
+	_, _, err = traitCatalog.apply(&environment)
 
 	require.NoError(t, err)
 	assert.NotEmpty(t, environment.ExecutedTraits)
@@ -710,7 +717,7 @@ func TestKnativeMultipleTrigger(t *testing.T) {
 				Traits: v1.Traits{
 					Knative: &traitv1.KnativeTrait{
 						Trait: traitv1.Trait{
-							Enabled: pointer.Bool(true),
+							Enabled: ptr.To(true),
 						},
 					},
 				},
@@ -742,7 +749,7 @@ func TestKnativeMultipleTrigger(t *testing.T) {
 	environment.Platform.ResyncStatusFullConfig()
 
 	// don't care about conditions in this unit test
-	_, err = traitCatalog.apply(&environment)
+	_, _, err = traitCatalog.apply(&environment)
 
 	require.NoError(t, err)
 	assert.NotEmpty(t, environment.ExecutedTraits)
@@ -847,7 +854,7 @@ func TestKnativeMultipleTriggerAdditionalFilterConfig(t *testing.T) {
 				Traits: v1.Traits{
 					Knative: &traitv1.KnativeTrait{
 						Trait: traitv1.Trait{
-							Enabled: pointer.Bool(true),
+							Enabled: ptr.To(true),
 						},
 						Filters: []string{"subject=Hello"},
 					},
@@ -880,7 +887,7 @@ func TestKnativeMultipleTriggerAdditionalFilterConfig(t *testing.T) {
 	environment.Platform.ResyncStatusFullConfig()
 
 	// don't care about conditions in this unit test
-	_, err = traitCatalog.apply(&environment)
+	_, _, err = traitCatalog.apply(&environment)
 
 	require.NoError(t, err)
 	assert.NotEmpty(t, environment.ExecutedTraits)
@@ -983,7 +990,7 @@ func TestKnativeTriggerNoEventType(t *testing.T) {
 				Traits: v1.Traits{
 					Knative: &traitv1.KnativeTrait{
 						Trait: traitv1.Trait{
-							Enabled: pointer.Bool(true),
+							Enabled: ptr.To(true),
 						},
 					},
 				},
@@ -1015,7 +1022,7 @@ func TestKnativeTriggerNoEventType(t *testing.T) {
 	environment.Platform.ResyncStatusFullConfig()
 
 	// don't care about conditions in this unit test
-	_, err = traitCatalog.apply(&environment)
+	_, _, err = traitCatalog.apply(&environment)
 
 	require.NoError(t, err)
 	assert.NotEmpty(t, environment.ExecutedTraits)
@@ -1080,7 +1087,7 @@ func TestKnativeTriggerNoServingAvailable(t *testing.T) {
 				Traits: v1.Traits{
 					Knative: &traitv1.KnativeTrait{
 						Trait: traitv1.Trait{
-							Enabled: pointer.Bool(true),
+							Enabled: ptr.To(true),
 						},
 					},
 				},
@@ -1112,7 +1119,7 @@ func TestKnativeTriggerNoServingAvailable(t *testing.T) {
 	environment.Platform.ResyncStatusFullConfig()
 
 	// don't care about conditions in this unit test
-	_, err = traitCatalog.apply(&environment)
+	_, _, err = traitCatalog.apply(&environment)
 
 	require.NoError(t, err)
 	assert.NotEmpty(t, environment.ExecutedTraits)
@@ -1173,7 +1180,7 @@ func TestKnativePlatformHttpConfig(t *testing.T) {
 			err = tc.Configure(&environment)
 			require.NoError(t, err)
 
-			_, err = tc.apply(&environment)
+			_, _, err = tc.apply(&environment)
 			require.NoError(t, err)
 			assert.Contains(t, environment.Integration.Status.Capabilities, v1.CapabilityPlatformHTTP)
 		})
@@ -1219,8 +1226,9 @@ func TestKnativePlatformHttpDependencies(t *testing.T) {
 			err = tc.Configure(&environment)
 			require.NoError(t, err)
 
-			conditions, err := tc.apply(&environment)
+			conditions, traits, err := tc.apply(&environment)
 			require.NoError(t, err)
+			assert.NotEmpty(t, traits)
 			assert.NotEmpty(t, conditions)
 			assert.Contains(t, environment.Integration.Status.Capabilities, v1.CapabilityPlatformHTTP)
 			assert.Contains(t, environment.Integration.Status.Dependencies, "mvn:org.apache.camel.quarkus:camel-quarkus-platform-http")
@@ -1229,6 +1237,8 @@ func TestKnativePlatformHttpDependencies(t *testing.T) {
 }
 
 func TestKnativeEnabled(t *testing.T) {
+	client, err := test.NewFakeClient()
+	require.NoError(t, err)
 	catalog, err := camel.DefaultCatalog()
 	require.NoError(t, err)
 
@@ -1237,6 +1247,7 @@ func TestKnativeEnabled(t *testing.T) {
 	environment := Environment{
 		CamelCatalog: catalog,
 		Catalog:      traitCatalog,
+		Client:       client,
 		Integration: &v1.Integration{
 			ObjectMeta: metav1.ObjectMeta{
 				Name:      "test",
@@ -1293,12 +1304,12 @@ func TestKnativeEnabled(t *testing.T) {
 
 	// apply the knative trait
 	require.NoError(t, knTrait.Apply(&environment))
-
-	assert.True(t, *knTrait.Enabled)
 	assert.Contains(t, environment.Integration.Status.Capabilities, v1.CapabilityKnative)
 }
 
 func TestKnativeNotEnabled(t *testing.T) {
+	client, err := test.NewFakeClient()
+	require.NoError(t, err)
 	catalog, err := camel.DefaultCatalog()
 	require.NoError(t, err)
 
@@ -1307,6 +1318,7 @@ func TestKnativeNotEnabled(t *testing.T) {
 	environment := Environment{
 		CamelCatalog: catalog,
 		Catalog:      traitCatalog,
+		Client:       client,
 		Integration: &v1.Integration{
 			ObjectMeta: metav1.ObjectMeta{
 				Name:      "test",
@@ -1393,7 +1405,7 @@ func NewFakeEnvironment(t *testing.T, source v1.SourceSpec) Environment {
 				Traits: v1.Traits{
 					Knative: &traitv1.KnativeTrait{
 						Trait: traitv1.Trait{
-							Enabled: pointer.Bool(true),
+							Enabled: ptr.To(true),
 						},
 					},
 				},
@@ -1448,7 +1460,7 @@ func NewFakeEnvironmentForSyntheticKit(t *testing.T) Environment {
 				Traits: v1.Traits{
 					Knative: &traitv1.KnativeTrait{
 						Trait: traitv1.Trait{
-							Enabled: pointer.Bool(true),
+							Enabled: ptr.To(true),
 						},
 					},
 				},
@@ -1642,7 +1654,7 @@ func TestKnativeSinkBinding(t *testing.T) {
 	err = tc.Configure(&environment)
 	require.NoError(t, err)
 
-	_, err = tc.apply(&environment)
+	_, _, err = tc.apply(&environment)
 	require.NoError(t, err)
 	baseProp := "camel.component.knative.environment.resources[0]"
 	assert.Equal(t, "channel-sink-1", environment.ApplicationProperties[baseProp+".name"])
@@ -1691,16 +1703,167 @@ func TestKnativeSyntheticKitDefault(t *testing.T) {
 	ok, condition, err := knTrait.Configure(&e)
 	require.NoError(t, err)
 	assert.False(t, ok)
-	assert.NotNil(t, condition)
+	assert.Nil(t, condition)
 }
 
 func TestKnativeSyntheticKitEnabled(t *testing.T) {
 	e := NewFakeEnvironmentForSyntheticKit(t)
 	knTrait, _ := newKnativeTrait().(*knativeTrait)
-	knTrait.Enabled = pointer.Bool(true)
-	knTrait.Auto = pointer.Bool(false)
+	knTrait.Enabled = ptr.To(true)
 	ok, condition, err := knTrait.Configure(&e)
 	require.NoError(t, err)
 	assert.True(t, ok)
 	assert.Nil(t, condition)
 }
+
+func TestRunKnativeEndpointWithKnativeNotInstalled(t *testing.T) {
+	environment := createEnvironmentMissingEventingCRDs()
+	trait, _ := newKnativeTrait().(*knativeTrait)
+	environment.Integration.Spec.Sources = []v1.SourceSpec{
+		{
+			DataSpec: v1.DataSpec{
+				Name: "test.java",
+				Content: `
+				from("knative:channel/test").to("log:${body};
+			`,
+			},
+			Language: v1.LanguageJavaSource,
+		},
+	}
+	expectedCondition := NewIntegrationCondition(
+		"Knative",
+		v1.IntegrationConditionKnativeAvailable,
+		corev1.ConditionFalse,
+		v1.IntegrationConditionKnativeNotInstalledReason,
+		"integration cannot run. Knative is not installed in the cluster",
+	)
+	configured, condition, err := trait.Configure(environment)
+	require.Error(t, err)
+	assert.Equal(t, expectedCondition, condition)
+	assert.False(t, configured)
+}
+
+func TestRunNonKnativeEndpointWithKnativeNotInstalled(t *testing.T) {
+	environment := createEnvironmentMissingEventingCRDs()
+	trait, _ := newKnativeTrait().(*knativeTrait)
+	environment.Integration.Spec.Sources = []v1.SourceSpec{
+		{
+			DataSpec: v1.DataSpec{
+				Name: "test.java",
+				Content: `
+				from("platform-http://my-site").to("log:${body}");
+			`,
+			},
+			Language: v1.LanguageJavaSource,
+		},
+	}
+
+	configured, condition, err := trait.Configure(environment)
+	require.NoError(t, err)
+	assert.Nil(t, condition)
+	assert.False(t, configured)
+	conditions := environment.Integration.Status.Conditions
+	assert.Empty(t, conditions)
+}
+
+func createEnvironmentMissingEventingCRDs() *Environment {
+	client, _ := test.NewFakeClient()
+	// disable the knative eventing api
+	fakeClient := client.(*test.FakeClient) //nolint
+	fakeClient.DisableAPIGroupDiscovery("eventing.knative.dev/v1")
+
+	replicas := int32(3)
+	catalog, _ := camel.QuarkusCatalog()
+
+	environment := &Environment{
+		CamelCatalog: catalog,
+		Catalog:      NewCatalog(nil),
+		Client:       client,
+		Integration: &v1.Integration{
+			ObjectMeta: metav1.ObjectMeta{
+				Name: "integration-name",
+			},
+			Spec: v1.IntegrationSpec{
+				Replicas: &replicas,
+				Traits:   v1.Traits{},
+			},
+			Status: v1.IntegrationStatus{
+				Phase: v1.IntegrationPhaseInitialization,
+			},
+		},
+		Platform: &v1.IntegrationPlatform{
+			ObjectMeta: metav1.ObjectMeta{
+				Namespace: "namespace",
+			},
+			Spec: v1.IntegrationPlatformSpec{
+				Cluster: v1.IntegrationPlatformClusterKubernetes,
+				Profile: v1.TraitProfileKubernetes,
+			},
+		},
+		Resources:             kubernetes.NewCollection(),
+		ApplicationProperties: make(map[string]string),
+	}
+	environment.Platform.ResyncStatusFullConfig()
+
+	return environment
+}
+
+func TestKnativeAutoConfiguration(t *testing.T) {
+	client, _ := test.NewFakeClient()
+	replicas := int32(3)
+	catalog, _ := camel.QuarkusCatalog()
+	environment := &Environment{
+		CamelCatalog: catalog,
+		Catalog:      NewCatalog(nil),
+		Client:       client,
+		Integration: &v1.Integration{
+			ObjectMeta: metav1.ObjectMeta{
+				Name: "integration-name",
+			},
+			Spec: v1.IntegrationSpec{
+				Replicas: &replicas,
+				Traits:   v1.Traits{},
+			},
+			Status: v1.IntegrationStatus{
+				Phase: v1.IntegrationPhaseInitialization,
+			},
+		},
+		Platform: &v1.IntegrationPlatform{
+			ObjectMeta: metav1.ObjectMeta{
+				Namespace: "namespace",
+			},
+			Spec: v1.IntegrationPlatformSpec{
+				Cluster: v1.IntegrationPlatformClusterKubernetes,
+				Profile: v1.TraitProfileKubernetes,
+			},
+		},
+		Resources:             kubernetes.NewCollection(),
+		ApplicationProperties: make(map[string]string),
+	}
+	environment.Platform.ResyncStatusFullConfig()
+
+	trait, _ := newKnativeTrait().(*knativeTrait)
+	environment.Integration.Spec.Sources = []v1.SourceSpec{
+		{
+			DataSpec: v1.DataSpec{
+				Name: "test.java",
+				Content: `
+				from("knative:channel/test").to("log:${body};
+			`,
+			},
+			Language: v1.LanguageJavaSource,
+		},
+	}
+
+	configured, condition, err := trait.Configure(environment)
+	require.NoError(t, err)
+	assert.Nil(t, condition)
+	assert.True(t, configured)
+	err = trait.Apply(environment)
+	require.NoError(t, err)
+	expectedTrait, _ := newKnativeTrait().(*knativeTrait)
+	expectedTrait.Enabled = ptr.To(true)
+	expectedTrait.SinkBinding = ptr.To(false)
+	expectedTrait.ChannelSources = []string{"knative:channel/test"}
+	assert.Equal(t, expectedTrait, trait)
+}
