@@ -18,11 +18,10 @@ limitations under the License.
 package trait
 
 import (
-	"k8s.io/utils/pointer"
-
 	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
 	"github.com/apache/camel-k/v2/pkg/util/boolean"
 	"github.com/apache/camel-k/v2/pkg/util/envvar"
+	"k8s.io/utils/ptr"
 )
 
 const (
@@ -45,25 +44,22 @@ type loggingTrait struct {
 func newLoggingTraitTrait() Trait {
 	return &loggingTrait{
 		BaseTrait: NewBaseTrait(loggingTraitID, loggingTraitOrder),
-		LoggingTrait: traitv1.LoggingTrait{
-			Level: defaultLogLevel,
-		},
 	}
 }
 
-func (l loggingTrait) Configure(e *Environment) (bool, *TraitCondition, error) {
+func (l *loggingTrait) Configure(e *Environment) (bool, *TraitCondition, error) {
 	if e.Integration == nil {
 		return false, nil, nil
 	}
-	if !pointer.BoolDeref(l.Enabled, true) {
+	if !ptr.Deref(l.Enabled, true) {
 		return false, NewIntegrationConditionUserDisabled("Logging"), nil
 	}
 
 	return e.IntegrationInRunningPhases(), nil, nil
 }
 
-func (l loggingTrait) Apply(e *Environment) error {
-	if e.CamelCatalog != nil && e.CamelCatalog.Runtime.Capabilities["logging"].RuntimeProperties != nil {
+func (l *loggingTrait) Apply(e *Environment) error {
+	if e.CamelCatalog.Runtime.Capabilities["logging"].RuntimeProperties != nil {
 		l.setCatalogConfiguration(e)
 	} else {
 		l.setEnvConfiguration(e)
@@ -73,45 +69,45 @@ func (l loggingTrait) Apply(e *Environment) error {
 }
 
 // Deprecated: to be removed in future release in favor of func setCatalogConfiguration().
-func (l loggingTrait) setEnvConfiguration(e *Environment) {
-	envvar.SetVal(&e.EnvVars, envVarQuarkusLogLevel, l.Level)
+func (l *loggingTrait) setEnvConfiguration(e *Environment) {
+	envvar.SetVal(&e.EnvVars, envVarQuarkusLogLevel, l.getLevel())
 
 	if l.Format != "" {
 		envvar.SetVal(&e.EnvVars, envVarQuarkusLogConsoleFormat, l.Format)
 	}
 
-	if pointer.BoolDeref(l.JSON, false) {
+	if ptr.Deref(l.JSON, false) {
 		envvar.SetVal(&e.EnvVars, envVarQuarkusLogConsoleJSON, boolean.TrueString)
-		if pointer.BoolDeref(l.JSONPrettyPrint, false) {
+		if ptr.Deref(l.JSONPrettyPrint, false) {
 			envvar.SetVal(&e.EnvVars, envVarQuarkusLogConsoleJSONPrettyPrint, boolean.TrueString)
 		}
 	} else {
 		// If the trait is false OR unset, we default to false.
 		envvar.SetVal(&e.EnvVars, envVarQuarkusLogConsoleJSON, boolean.FalseString)
 
-		if pointer.BoolDeref(l.Color, true) {
+		if ptr.Deref(l.Color, true) {
 			envvar.SetVal(&e.EnvVars, envVarQuarkusConsoleColor, boolean.TrueString)
 		}
 	}
 }
 
-func (l loggingTrait) setCatalogConfiguration(e *Environment) {
+func (l *loggingTrait) setCatalogConfiguration(e *Environment) {
 	if e.ApplicationProperties == nil {
 		e.ApplicationProperties = make(map[string]string)
 	}
-	e.ApplicationProperties["camel.k.logging.level"] = l.Level
+	e.ApplicationProperties["camel.k.logging.level"] = l.getLevel()
 	if l.Format != "" {
 		e.ApplicationProperties["camel.k.logging.format"] = l.Format
 	}
-	if pointer.BoolDeref(l.JSON, false) {
+	if ptr.Deref(l.JSON, false) {
 		e.ApplicationProperties["camel.k.logging.json"] = boolean.TrueString
-		if pointer.BoolDeref(l.JSONPrettyPrint, false) {
+		if ptr.Deref(l.JSONPrettyPrint, false) {
 			e.ApplicationProperties["camel.k.logging.jsonPrettyPrint"] = boolean.TrueString
 		}
 	} else {
 		// If the trait is false OR unset, we default to false.
 		e.ApplicationProperties["camel.k.logging.json"] = boolean.FalseString
-		if pointer.BoolDeref(l.Color, true) {
+		if ptr.Deref(l.Color, true) {
 			e.ApplicationProperties["camel.k.logging.color"] = boolean.TrueString
 		}
 	}
@@ -122,3 +118,11 @@ func (l loggingTrait) setCatalogConfiguration(e *Environment) {
 		}
 	}
 }
+
+func (l *loggingTrait) getLevel() string {
+	if l.Level == "" {
+		return defaultLogLevel
+	}
+
+	return l.Level
+}
