@@ -62,12 +62,19 @@ func newOpenAPITrait() Trait {
 }
 
 func (t *openAPITrait) Configure(e *Environment) (bool, *TraitCondition, error) {
-	if !e.IntegrationInPhase(v1.IntegrationPhaseInitialization) {
-		return false, nil, nil
-	}
-
 	if t.Configmaps != nil {
-		return e.IntegrationInPhase(v1.IntegrationPhaseInitialization), nil, nil
+		if e.IntegrationInPhase(v1.IntegrationPhaseInitialization) {
+			condition := NewIntegrationCondition(
+				"OpenApi",
+				v1.IntegrationConditionTraitInfo,
+				corev1.ConditionTrue,
+				TraitConfigurationReason,
+				"OpenApi trait is deprecated and may be removed in future version: "+
+					"use Camel REST contract first instead, https://camel.apache.org/manual/rest-dsl-openapi.html",
+			)
+
+			return true, condition, nil
+		}
 	}
 
 	return false, nil, nil
@@ -202,13 +209,7 @@ func (t *openAPITrait) createNewOpenAPIConfigMap(e *Environment, resource v1.Dat
 		return err
 	}
 
-	// If the catalog is missing, we use the default version used by the IntegrationPlatform
-	runtimeVersion := e.Platform.Status.Build.RuntimeVersion
-	if e.CamelCatalog != nil {
-		runtimeVersion = e.CamelCatalog.Runtime.Version
-	}
-
-	project := t.generateMavenProject(runtimeVersion)
+	project := t.generateMavenProject(e.CamelCatalog.Runtime.Version)
 	mc := maven.NewContext(tmpDir)
 	mc.LocalRepository = e.Platform.Status.Build.Maven.LocalRepository
 	mc.AdditionalArguments = e.Platform.Status.Build.Maven.CLIOptions
