@@ -23,9 +23,11 @@ import (
 	"testing"
 	"time"
 
+	"github.com/apache/camel-k/v2/pkg/util"
 	"github.com/apache/camel-k/v2/pkg/util/boolean"
 	"github.com/apache/camel-k/v2/pkg/util/camel"
 	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
+	"github.com/apache/camel-k/v2/pkg/util/maven"
 	"github.com/apache/camel-k/v2/pkg/util/test"
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -71,7 +73,11 @@ func TestRestDslTraitApplicability(t *testing.T) {
 	enabled, condition, err = trait.Configure(e)
 	require.NoError(t, err)
 	assert.True(t, enabled)
-	assert.Nil(t, condition)
+	assert.NotNil(t, condition)
+	assert.Equal(t, "OpenApi trait is deprecated and may be removed in future version: "+
+		"use Camel REST contract first instead, https://camel.apache.org/manual/rest-dsl-openapi.html",
+		condition.message,
+	)
 }
 
 func TestRestDslTraitApplyError(t *testing.T) {
@@ -108,55 +114,129 @@ func TestRestDslTraitApplyError(t *testing.T) {
 }
 
 var openapi = `
-{
-  "swagger" : "2.0",
-  "info" : {
-    "version" : "1.0",
-    "title" : "Greeting REST API"
-  },
-  "host" : "",
-  "basePath" : "/camel/",
-  "tags" : [ {
-    "name" : "greetings",
-    "description" : "Greeting to {name}"
-  } ],
-  "schemes" : [ "http" ],
-  "paths" : {
-    "/greetings/{name}" : {
-      "get" : {
-        "tags" : [ "greetings" ],
-        "operationId" : "greeting-api",
-        "parameters" : [ {
-          "name" : "name",
-          "in" : "path",
-          "required" : true,
-          "type" : "string"
-        } ],
-        "responses" : {
-          "200" : {
-            "description" : "Output type",
-            "schema" : {
-              "$ref" : "#/definitions/Greetings"
-            }
-          }
-        }
-      }
-    }
-  },
-  "definitions" : {
-    "Greetings" : {
-      "type" : "object",
-      "properties" : {
-        "greetings" : {
-          "type" : "string"
-        }
-      }
-    }
-  }
-}
+openapi: "3.0.0"
+info:
+  version: 1.0.0
+  title: Swagger Petstore
+  license:
+    name: MIT
+servers:
+  - url: http://petstore.swagger.io/v1
+paths:
+  /pets:
+    get:
+      summary: List all pets
+      operationId: listPets
+      tags:
+        - pets
+      parameters:
+        - name: limit
+          in: query
+          description: How many items to return at one time (max 100)
+          required: false
+          schema:
+            type: integer
+            format: int32
+      responses:
+        '200':
+          description: A paged array of pets
+          headers:
+            x-next:
+              description: A link to the next page of responses
+              schema:
+                type: string
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Pets"
+        default:
+          description: unexpected error
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Error"
+    post:
+      summary: Create a pet
+      operationId: createPets
+      tags:
+        - pets
+      responses:
+        '201':
+          description: Null response
+        default:
+          description: unexpected error
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Error"
+  /pets/{petId}:
+    get:
+      summary: Info for a specific pet
+      operationId: showPetById
+      tags:
+        - pets
+      parameters:
+        - name: petId
+          in: path
+          required: true
+          description: The id of the pet to retrieve
+          schema:
+            type: string
+      responses:
+        '200':
+          description: Expected response to a valid request
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Pet"
+        default:
+          description: unexpected error
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Error"
+components:
+  schemas:
+    Pet:
+      type: object
+      required:
+        - id
+        - name
+      properties:
+        id:
+          type: integer
+          format: int64
+        name:
+          type: string
+        tag:
+          type: string
+    Pets:
+      type: array
+      items:
+        $ref: "#/components/schemas/Pet"
+    Error:
+      type: object
+      required:
+        - code
+        - message
+      properties:
+        code:
+          type: integer
+          format: int32
+        message:
+          type: string
 `
 
 func TestRestDslTraitApplyWorks(t *testing.T) {
+	settings, err := maven.NewSettings(
+		maven.Repositories(
+			"https://repository.apache.org/content/groups/snapshots-group@id=apache@snapshots@noreleases",
+		),
+	)
+	require.NoError(t, err)
+	content, err := util.EncodeXML(settings)
+	require.NoError(t, err)
+	cm := kubernetes.NewConfigMap("default", "maven-settings", "settings.xml", "settings.xml", string(content), nil)
 	catalog, err := camel.DefaultCatalog()
 	require.NoError(t, err)
 	fakeClient, _ := test.NewFakeClient(&corev1.ConfigMap{
@@ -165,15 +245,21 @@ func TestRestDslTraitApplyWorks(t *testing.T) {
 			Namespace: "default",
 		},
 		Data: map[string]string{
-			"greetings-api.json": openapi,
+			"pets.yaml": openapi,
 		},
-	})
+	},
+		cm,
+	)
 
 	e := &Environment{
 		Ctx:          context.Background(),
 		CamelCatalog: catalog,
 		Client:       fakeClient,
 		Platform: &v1.IntegrationPlatform{
+			ObjectMeta: metav1.ObjectMeta{
+				Name:      "camel-k",
+				Namespace: "default",
+			},
 			Spec: v1.IntegrationPlatformSpec{
 				Cluster: v1.IntegrationPlatformClusterKubernetes,
 			},
@@ -184,8 +270,17 @@ func TestRestDslTraitApplyWorks(t *testing.T) {
 						PublishStrategy: v1.IntegrationPlatformBuildPublishStrategyJib,
 						Registry:        v1.RegistrySpec{Address: "registry"},
 						RuntimeVersion:  catalog.Runtime.Version,
-						Maven:           v1.MavenSpec{},
-						Timeout:         &metav1.Duration{Duration: time.Minute},
+						Maven: v1.MavenSpec{
+							Settings: v1.ValueSource{
+								ConfigMapKeyRef: &corev1.ConfigMapKeySelector{
+									LocalObjectReference: corev1.LocalObjectReference{
+										Name: cm.Name,
+									},
+									Key: "settings.xml",
+								},
+							},
+						},
+						Timeout: &metav1.Duration{Duration: time.Minute},
 					},
 				},
 				Phase: v1.IntegrationPlatformPhaseReady,
@@ -228,5 +323,5 @@ func TestRestDslTraitApplyWorks(t *testing.T) {
 		return cm.Name == "hello-openapi-000"
 	})
 	assert.NotNil(t, sourceCm)
-	assert.Contains(t, sourceCm.Data["content"], "get id=\"greeting-api\" path=\"/greetings/{name}")
+	assert.Contains(t, sourceCm.Data["content"], "get id=\"showPetById\" path=\"/pets/{petId}\"")
 }
