@@ -29,6 +29,7 @@ import (
 )
 
 // LookupConfigmap will look for any k8s Configmap with a given name in a given namespace.
+// Deprecated: won't be supported in future releases.
 func LookupConfigmap(ctx context.Context, c client.Client, ns string, name string) *corev1.ConfigMap {
 	cm := corev1.ConfigMap{
 		TypeMeta: metav1.TypeMeta{
@@ -62,6 +63,7 @@ func LookupResourceVersion(ctx context.Context, c client.Client, object ctrl.Obj
 }
 
 // LookupSecret will look for any k8s Secret with a given name in a given namespace.
+// Deprecated: won't be supported in future releases.
 func LookupSecret(ctx context.Context, c client.Client, ns string, name string) *corev1.Secret {
 	secret := corev1.Secret{
 		TypeMeta: metav1.TypeMeta{
@@ -109,7 +111,31 @@ func LookupPersistentVolumeClaim(ctx context.Context, c client.Client, ns string
 	return &pvc, nil
 }
 
-// LookupDefaultStorageClass will look for the default k8s StorageClass in a given namespace.
+// LookupStorageClass will look for any k8s StorageClass with a given name in a given namespace.
+func LookupStorageClass(ctx context.Context, c client.Client, ns string, name string) (*storagev1.StorageClass, error) {
+	sc := storagev1.StorageClass{
+		TypeMeta: metav1.TypeMeta{
+			Kind:       "StorageClass",
+			APIVersion: storagev1.SchemeGroupVersion.String(),
+		},
+		ObjectMeta: metav1.ObjectMeta{
+			Namespace: ns,
+			Name:      name,
+		},
+	}
+	key := ctrl.ObjectKey{
+		Namespace: ns,
+		Name:      name,
+	}
+	if err := c.Get(ctx, key, &sc); err != nil && k8serrors.IsNotFound(err) {
+		return nil, nil
+	} else if err != nil {
+		return nil, err
+	}
+	return &sc, nil
+}
+
+// LookupDefaultStorageClass will look for the default k8s StorageClass in the cluster.
 func LookupDefaultStorageClass(ctx context.Context, c client.Client) (*storagev1.StorageClass, error) {
 	storageClasses, err := c.StorageV1().StorageClasses().List(ctx, metav1.ListOptions{})
 	if err != nil {
