@@ -18,14 +18,18 @@ limitations under the License.
 package source
 
 import (
+	"strings"
+
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	"github.com/apache/camel-k/v2/pkg/util"
 )
 
+// JavaScriptInspector inspects Javascript DSL spec.
 type JavaScriptInspector struct {
 	baseInspector
 }
 
+// Extract extracts all metadata from source spec.
 func (i JavaScriptInspector) Extract(source v1.SourceSpec, meta *Metadata) error {
 	from := util.FindAllDistinctStringSubmatch(
 		source.Content,
@@ -54,3 +58,28 @@ func (i JavaScriptInspector) Extract(source v1.SourceSpec, meta *Metadata) error
 
 	return i.extract(source, meta, from, to, kameletEips, hasRest)
 }
+
+// ReplaceFromURI parses the source content and replace the `from` URI configuration with the a new URI. Returns true if it applies a replacement.
+func (i JavaScriptInspector) ReplaceFromURI(source *v1.SourceSpec, newFromURI string) (bool, error) {
+	froms := util.FindAllDistinctStringSubmatch(
+		source.Content,
+		singleQuotedFrom,
+		doubleQuotedFrom,
+		singleQuotedFromF,
+		doubleQuotedFromF,
+	)
+	newContent := source.Content
+	if froms == nil {
+		return false, nil
+	}
+	for _, from := range froms {
+		newContent = strings.ReplaceAll(newContent, from, newFromURI)
+	}
+	replaced := newContent != source.Content
+
+	if replaced {
+		source.Content = newContent
+	}
+
+	return replaced, nil
+}
