@@ -31,18 +31,8 @@ target_remote=$2
 git branch -D ${target_staging} || true
 git checkout -b ${target_staging}
 git add * || true
-git commit -a -m "Release ${target_version}"
+git commit -a -m "Release ${target_version}" || true
 
 git tag --force ${target_tag} ${target_staging}
 git push --force ${target_remote} ${target_tag}
 echo "Tag ${target_tag} pushed to ${target_remote}"
-
-api_tag="pkg/apis/camel/$target_tag"
-git tag --force ${api_tag} ${target_staging}
-git push --force ${target_remote} ${api_tag}
-echo "Tag ${api_tag} pushed to ${target_remote}"
-
-client_tag="pkg/client/camel/$target_tag"
-git tag --force ${client_tag} ${target_staging}
-git push --force ${target_remote} ${client_tag}
-echo "Tag ${client_tag} pushed to ${target_remote}"
